@@ -7,7 +7,7 @@ import os
 import sys
 import warnings
 
-if sys.version_info < (3,):
+if sys.version_info < (3,):  # pragma: no cover
     sys.stderr.write(
         "\n\nAfter the Sodium release, 3001, Salt no longer supports Python 2. Exiting.\n\n"
     )
@@ -22,7 +22,7 @@ class TornadoImporter:
         if USE_VENDORED_TORNADO:
             if module_name.startswith("tornado"):
                 return self
-        else:
+        else:  # pragma: no cover
             if module_name.startswith("salt.ext.tornado"):
                 return self
         return None
@@ -30,7 +30,7 @@ class TornadoImporter:
     def create_module(self, spec):
         if USE_VENDORED_TORNADO:
             mod = importlib.import_module("salt.ext.{}".format(spec.name))
-        else:
+        else:  # pragma: no cover
             # Remove 'salt.ext.' from the module
             mod = importlib.import_module(spec.name[9:])
         sys.modules[spec.name] = mod
@@ -118,62 +118,29 @@ warnings.filterwarnings(
     category=DeprecationWarning,
 )
 
+warnings.filterwarnings(
+    "ignore",
+    "Deprecated call to `pkg_resources.declare_namespace.*",
+    category=DeprecationWarning,
+)
+warnings.filterwarnings(
+    "ignore",
+    ".*pkg_resources is deprecated as an API.*",
+    category=DeprecationWarning,
+)
+
 
 def __define_global_system_encoding_variable__():
-    import sys
-
-    # This is the most trustworthy source of the system encoding, though, if
-    # salt is being imported after being daemonized, this information is lost
-    # and reset to None
-    encoding = None
-
-    if not sys.platform.startswith("win") and sys.stdin is not None:
-        # On linux we can rely on sys.stdin for the encoding since it
-        # most commonly matches the filesystem encoding. This however
-        # does not apply to windows
-        encoding = sys.stdin.encoding
-
-    if not encoding:
-        # If the system is properly configured this should return a valid
-        # encoding. MS Windows has problems with this and reports the wrong
-        # encoding
-        import locale
-
-        try:
-            encoding = locale.getencoding()
-        except AttributeError:
-            # Python < 3.11
-            encoding = locale.getpreferredencoding(do_setlocale=True)
-
-        # This is now garbage collectable
-        del locale
-
-        if not encoding:
-            # This is most likely ascii which is not the best but we were
-            # unable to find a better encoding. If this fails, we fall all
-            # the way back to ascii
-            encoding = sys.getdefaultencoding()
-        if not encoding:
-            if sys.platform.startswith("darwin"):
-                # Mac OS X uses UTF-8
-                encoding = "utf-8"
-            elif sys.platform.startswith("win"):
-                # Windows uses a configurable encoding; on Windows, Python uses the name “mbcs”
-                # to refer to whatever the currently configured encoding is.
-                encoding = "mbcs"
-            else:
-                # On linux default to ascii as a last resort
-                encoding = "ascii"
 
     import builtins
+    import sys
 
     # Define the detected encoding as a built-in variable for ease of use
-    setattr(builtins, "__salt_system_encoding__", encoding)
+    setattr(builtins, "__salt_system_encoding__", sys.getdefaultencoding())
 
     # This is now garbage collectable
-    del sys
     del builtins
-    del encoding
+    del sys
 
 
 __define_global_system_encoding_variable__()
