@@ -3,33 +3,31 @@ The caller module is used as a front-end to manage direct calls to the salt
 minion modules.
 """
 
-
 import logging
 import os
 import sys
 import traceback
 
 import salt
+import salt.channel.client
 import salt.defaults.exitcodes
 import salt.loader
 import salt.minion
 import salt.output
 import salt.payload
-import salt.transport
-import salt.transport.client
 import salt.utils.args
 import salt.utils.files
 import salt.utils.jid
 import salt.utils.minion
 import salt.utils.profile
 import salt.utils.stringutils
+from salt._logging import LOG_LEVELS
 from salt.exceptions import (
     CommandExecutionError,
     CommandNotFoundError,
     SaltClientError,
     SaltInvocationError,
 )
-from salt.log import LOG_LEVELS
 
 log = logging.getLogger(__name__)
 
@@ -41,21 +39,7 @@ class Caller:
 
     @staticmethod
     def factory(opts, **kwargs):
-        # Default to ZeroMQ for now
-        ttype = "zeromq"
-
-        # determine the ttype
-        if "transport" in opts:
-            ttype = opts["transport"]
-        elif "transport" in opts.get("pillar", {}).get("master", {}):
-            ttype = opts["pillar"]["master"]["transport"]
-
-        # switch on available ttypes
-        if ttype in ("zeromq", "tcp", "detect"):
-            return ZeroMQCaller(opts, **kwargs)
-        else:
-            raise Exception("Callers are only defined for ZeroMQ and TCP")
-            # return NewKindOfCaller(opts, **kwargs)
+        return ZeroMQCaller(opts, **kwargs)
 
 
 class BaseCaller:
@@ -69,7 +53,6 @@ class BaseCaller:
         """
         self.opts = opts
         self.opts["caller"] = True
-        self.serial = salt.payload.Serial(self.opts)
         # Handle this here so other deeper code which might
         # be imported as part of the salt api doesn't do  a
         # nasty sys.exit() and tick off our developer users
@@ -131,7 +114,7 @@ class BaseCaller:
             # _retcode will be available in the kwargs of the outputter function
             if self.opts.get("retcode_passthrough", False):
                 sys.exit(ret["retcode"])
-            elif ret["retcode"] != salt.defaults.exitcodes.EX_OK:
+            elif ret.get("retcode") != salt.defaults.exitcodes.EX_OK:
                 sys.exit(salt.defaults.exitcodes.EX_GENERIC)
         except SaltInvocationError as err:
             raise SystemExit(err)
@@ -185,7 +168,7 @@ class BaseCaller:
             )
             try:
                 with salt.utils.files.fopen(proc_fn, "w+b") as fp_:
-                    fp_.write(self.serial.dumps(sdata))
+                    fp_.write(salt.payload.dumps(sdata))
             except NameError:
                 # Don't require msgpack with local
                 pass
@@ -294,7 +277,7 @@ class BaseCaller:
                 pass
 
         # return the job infos back up to the respective minion's master
-        if not is_local:
+        if not is_local and not self.opts.get("no_return_event", False):
             try:
                 mret = ret.copy()
                 mret["jid"] = "req"
@@ -323,7 +306,7 @@ class ZeroMQCaller(BaseCaller):
         """
         Return the data up to the master
         """
-        with salt.transport.client.ReqChannel.factory(
+        with salt.channel.client.ReqChannel.factory(
             self.opts, usage="salt_call"
         ) as channel:
             load = {"cmd": "_return", "id": self.opts["id"]}
