@@ -197,7 +197,9 @@ def list_nodes_select(call=None):
     Return a list of the VMs that are on the provider, with select fields
     """
     return salt.utils.cloud.list_nodes_select(
-        list_nodes_full("function"), __opts__["query.selection"], call,
+        list_nodes_full("function"),
+        __opts__["query.selection"],
+        call,
     )
 
 
@@ -349,11 +351,16 @@ def create(vm_):
         kwargs["ssh_interface"] = ssh_interface
     else:
         raise SaltCloudConfigError(
-            "The DigitalOcean driver requires ssh_interface to be defined as 'public' or 'private'."
+            "The DigitalOcean driver requires ssh_interface to be defined as 'public'"
+            " or 'private'."
         )
 
     private_networking = config.get_cloud_config_value(
-        "private_networking", vm_, __opts__, search_global=False, default=None,
+        "private_networking",
+        vm_,
+        __opts__,
+        search_global=False,
+        default=None,
     )
 
     if private_networking is not None:
@@ -370,7 +377,11 @@ def create(vm_):
         )
 
     backups_enabled = config.get_cloud_config_value(
-        "backups_enabled", vm_, __opts__, search_global=False, default=None,
+        "backups_enabled",
+        vm_,
+        __opts__,
+        search_global=False,
+        default=None,
     )
 
     if backups_enabled is not None:
@@ -379,7 +390,11 @@ def create(vm_):
         kwargs["backups"] = backups_enabled
 
     ipv6 = config.get_cloud_config_value(
-        "ipv6", vm_, __opts__, search_global=False, default=None,
+        "ipv6",
+        vm_,
+        __opts__,
+        search_global=False,
+        default=None,
     )
 
     if ipv6 is not None:
@@ -388,7 +403,11 @@ def create(vm_):
         kwargs["ipv6"] = ipv6
 
     monitoring = config.get_cloud_config_value(
-        "monitoring", vm_, __opts__, search_global=False, default=None,
+        "monitoring",
+        vm_,
+        __opts__,
+        search_global=False,
+        default=None,
     )
 
     if monitoring is not None:
@@ -413,7 +432,11 @@ def create(vm_):
             log.exception("Failed to read userdata from %s: %s", userdata_file, exc)
 
     create_dns_record = config.get_cloud_config_value(
-        "create_dns_record", vm_, __opts__, search_global=False, default=None,
+        "create_dns_record",
+        vm_,
+        __opts__,
+        search_global=False,
+        default=None,
     )
 
     if create_dns_record:
@@ -422,7 +445,8 @@ def create(vm_):
         dns_domain_name = vm_["name"].split(".")
         if len(dns_domain_name) > 2:
             log.debug(
-                "create_dns_record: inferring default dns_hostname, dns_domain from minion name as FQDN"
+                "create_dns_record: inferring default dns_hostname, dns_domain from"
+                " minion name as FQDN"
             )
             default_dns_hostname = ".".join(dns_domain_name[:-2])
             default_dns_domain = ".".join(dns_domain_name[-2:])
@@ -677,7 +701,7 @@ def _get_node(name):
         except KeyError:
             attempts -= 1
             log.debug(
-                "Failed to get the data for node '%s'. Remaining " "attempts: %s",
+                "Failed to get the data for node '%s'. Remaining attempts: %s",
                 name,
                 attempts,
             )
@@ -701,7 +725,8 @@ def list_keypairs(call=None):
 
     while fetch:
         items = query(
-            method="account/keys", command="?page=" + str(page) + "&per_page=100",
+            method="account/keys",
+            command="?page=" + str(page) + "&per_page=100",
         )
 
         for key_pair in items["ssh_keys"]:
@@ -838,7 +863,7 @@ def destroy(name, call=None):
     """
     if call == "function":
         raise SaltCloudSystemExit(
-            "The destroy action must be called with -d, --destroy, " "-a or --action."
+            "The destroy action must be called with -d, --destroy, -a or --action."
         )
 
     __utils__["cloud.fire_event"](
@@ -1031,7 +1056,8 @@ def list_floating_ips(call=None):
 
     while fetch:
         items = query(
-            method="floating_ips", command="?page=" + str(page) + "&per_page=200",
+            method="floating_ips",
+            command="?page=" + str(page) + "&per_page=200",
         )
 
         for floating_ip in items["floating_ips"]:
