@@ -20,11 +20,10 @@ import traceback
 import uuid
 import weakref
 
+import salt.channel.client
 import salt.defaults.exitcodes
 import salt.ext.tornado.gen
 import salt.payload
-import salt.transport.client
-import salt.transport.frame
 import salt.utils.crypt
 import salt.utils.decorators
 import salt.utils.event
@@ -37,13 +36,14 @@ import salt.utils.verify
 import salt.version
 from salt.exceptions import (
     AuthenticationError,
+    InvalidKeyError,
     MasterExit,
     SaltClientError,
     SaltReqTimeoutError,
 )
 
 try:
-    from M2Crypto import RSA, EVP, BIO
+    from M2Crypto import BIO, EVP, RSA
 
     HAS_M2 = True
 except ImportError:
@@ -51,11 +51,12 @@ except ImportError:
 
 if not HAS_M2:
     try:
-        from Cryptodome.Cipher import AES, PKCS1_OAEP, PKCS1_v1_5 as PKCS1_v1_5_CIPHER
+        from Cryptodome import Random
+        from Cryptodome.Cipher import AES, PKCS1_OAEP
+        from Cryptodome.Cipher import PKCS1_v1_5 as PKCS1_v1_5_CIPHER
         from Cryptodome.Hash import SHA
         from Cryptodome.PublicKey import RSA
         from Cryptodome.Signature import PKCS1_v1_5
-        from Cryptodome import Random
 
         HAS_CRYPTO = True
     except ImportError:
@@ -63,18 +64,14 @@ if not HAS_M2:
 
 if not HAS_M2 and not HAS_CRYPTO:
     try:
-        from Crypto.Cipher import (  # nosec
-            AES,
-            PKCS1_OAEP,
-            PKCS1_v1_5 as PKCS1_v1_5_CIPHER,
-        )
+        # let this be imported, if possible
+        from Crypto import Random  # nosec
+        from Crypto.Cipher import AES, PKCS1_OAEP  # nosec
+        from Crypto.Cipher import PKCS1_v1_5 as PKCS1_v1_5_CIPHER  # nosec
         from Crypto.Hash import SHA  # nosec
         from Crypto.PublicKey import RSA  # nosec
         from Crypto.Signature import PKCS1_v1_5  # nosec
 
-        # let this be imported, if possible
-        from Crypto import Random  # nosec
-
         HAS_CRYPTO = True
     except ImportError:
         HAS_CRYPTO = False
@@ -83,6 +80,13 @@ if not HAS_M2 and not HAS_CRYPTO:
 log = logging.getLogger(__name__)
 
 
+def clean_key(key):
+    """
+    Clean the key so that it only has unix style line endings (\\n)
+    """
+    return "\n".join(key.strip().splitlines())
+
+
 def dropfile(cachedir, user=None):
     """
     Set an AES dropfile to request the master update the publish session key
@@ -185,7 +189,7 @@ def _get_key_with_evict(path, timestamp, passphrase):
     Load a private key from disk.  `timestamp` above is intended to be the
     timestamp of the file's last modification. This fn is memoized so if it is
     called with the same path and timestamp (the file's last modified time) the
-    second time the result is returned from the memoiziation.  If the file gets
+    second time the result is returned from the memoization.  If the file gets
     modified then the params are different and the key is loaded from disk.
     """
     log.debug("salt.crypt._get_key_with_evict: Loading private key")
@@ -221,10 +225,16 @@ def get_rsa_pub_key(path):
         with salt.utils.files.fopen(path, "rb") as f:
             data = f.read().replace(b"RSA ", b"")
         bio = BIO.MemoryBuffer(data)
-        key = RSA.load_pub_key_bio(bio)
+        try:
+            key = RSA.load_pub_key_bio(bio)
+        except RSA.RSAError:
+            raise InvalidKeyError("Encountered bad RSA public key")
     else:
         with salt.utils.files.fopen(path) as f:
-            key = RSA.importKey(f.read())
+            try:
+                key = RSA.importKey(f.read())
+            except (ValueError, IndexError, TypeError):
+                raise InvalidKeyError("Encountered bad RSA public key")
     return key
 
 
@@ -289,7 +299,7 @@ def gen_signature(priv_path, pub_path, sign_path, passphrase=None):
 
     if os.path.isfile(sign_path):
         log.trace(
-            "Signature file %s already exists, please remove it first and " "try again",
+            "Signature file %s already exists, please remove it first and try again",
             sign_path,
         )
     else:
@@ -374,7 +384,7 @@ class MasterKeys(dict):
                 )
                 if os.path.isfile(self.sig_path):
                     with salt.utils.files.fopen(self.sig_path) as fp_:
-                        self.pub_signature = fp_.read()
+                        self.pub_signature = clean_key(fp_.read())
                     log.info(
                         "Read %s's signature from %s",
                         os.path.basename(self.pub_path),
@@ -459,7 +469,7 @@ class MasterKeys(dict):
                 with salt.utils.files.fopen(path, "wb+") as wfh:
                     wfh.write(key.publickey().exportKey("PEM"))
         with salt.utils.files.fopen(path) as rfh:
-            return rfh.read()
+            return clean_key(rfh.read())
 
     def get_mkey_paths(self):
         return self.pub_path, self.rsa_path
@@ -534,7 +544,6 @@ class AsyncAuth:
         """
         self.opts = opts
         self.token = salt.utils.stringutils.to_bytes(Crypticle.generate_key_string())
-        self.serial = salt.payload.Serial(self.opts)
         self.pub_path = os.path.join(self.opts["pki_dir"], "minion.pub")
         self.rsa_path = os.path.join(self.opts["pki_dir"], "minion.pem")
         if self.opts["__role"] == "syndic":
@@ -639,7 +648,7 @@ class AsyncAuth:
             acceptance_wait_time_max = acceptance_wait_time
         creds = None
 
-        with salt.transport.client.AsyncReqChannel.factory(
+        with salt.channel.client.AsyncReqChannel.factory(
             self.opts, crypt="clear", io_loop=self.io_loop
         ) as channel:
             error = None
@@ -750,7 +759,7 @@ class AsyncAuth:
         close_channel = False
         if not channel:
             close_channel = True
-            channel = salt.transport.client.AsyncReqChannel.factory(
+            channel = salt.channel.client.AsyncReqChannel.factory(
                 self.opts, crypt="clear", io_loop=self.io_loop
             )
 
@@ -765,7 +774,8 @@ class AsyncAuth:
                 raise salt.ext.tornado.gen.Return("retry")
             else:
                 raise SaltClientError(
-                    "Attempt to authenticate with the salt master failed with timeout error"
+                    "Attempt to authenticate with the salt master failed with timeout"
+                    " error"
                 )
         finally:
             if close_channel:
@@ -783,7 +793,7 @@ class AsyncAuth:
 
         clear_signed_data = payload["load"]
         clear_signature = payload["sig"]
-        payload = self.serial.loads(clear_signed_data)
+        payload = salt.payload.loads(clear_signed_data)
 
         if "pub_key" in payload:
             auth["aes"] = self.verify_master(
@@ -833,11 +843,11 @@ class AsyncAuth:
                         "clean out the keys. The Salt Minion will now exit."
                     )
                     # Add a random sleep here for systems that are using a
-                    # a service manager to immediately restart the service
-                    # to avoid overloading the system
+                    # service manager to immediately restart the service to
+                    # avoid overloading the system
                     time.sleep(random.randint(10, 20))
                     sys.exit(salt.defaults.exitcodes.EX_NOPERM)
-            # has the master returned that its maxed out with minions?
+            # Has the master returned that it's maxed out with minions?
             elif payload["ret"] == "full":
                 return "full"
             else:
@@ -939,7 +949,7 @@ class AsyncAuth:
         except Exception:  # pylint: disable=broad-except
             pass
         with salt.utils.files.fopen(self.pub_path) as f:
-            payload["pub"] = f.read()
+            payload["pub"] = clean_key(f.read())
         return payload
 
     def decrypt_aes(self, payload, master_pub=True):
@@ -1071,7 +1081,7 @@ class AsyncAuth:
                 return False
         except Exception as sign_exc:  # pylint: disable=broad-except
             log.error(
-                "There was an error while verifying the masters public-key " "signature"
+                "There was an error while verifying the masters public-key signature"
             )
             raise Exception(sign_exc)
 
@@ -1162,11 +1172,9 @@ class AsyncAuth:
         m_pub_exists = os.path.isfile(m_pub_fn)
         if m_pub_exists and master_pub and not self.opts["open_mode"]:
             with salt.utils.files.fopen(m_pub_fn) as fp_:
-                local_master_pub = fp_.read()
+                local_master_pub = clean_key(fp_.read())
 
-            if payload["pub_key"].replace("\n", "").replace(
-                "\r", ""
-            ) != local_master_pub.replace("\n", "").replace("\r", ""):
+            if payload["pub_key"] != local_master_pub:
                 if not self.check_auth_deps(payload):
                     return ""
 
@@ -1281,7 +1289,6 @@ class SAuth(AsyncAuth):
         """
         self.opts = opts
         self.token = salt.utils.stringutils.to_bytes(Crypticle.generate_key_string())
-        self.serial = salt.payload.Serial(self.opts)
         self.pub_path = os.path.join(self.opts["pki_dir"], "minion.pub")
         self.rsa_path = os.path.join(self.opts["pki_dir"], "minion.pem")
         self._creds = None
@@ -1320,7 +1327,7 @@ class SAuth(AsyncAuth):
         acceptance_wait_time_max = self.opts["acceptance_wait_time_max"]
         if not acceptance_wait_time_max:
             acceptance_wait_time_max = acceptance_wait_time
-        with salt.transport.client.ReqChannel.factory(
+        with salt.channel.client.ReqChannel.factory(
             self.opts, crypt="clear"
         ) as channel:
             while True:
@@ -1398,7 +1405,7 @@ class SAuth(AsyncAuth):
         close_channel = False
         if not channel:
             close_channel = True
-            channel = salt.transport.client.ReqChannel.factory(self.opts, crypt="clear")
+            channel = salt.channel.client.ReqChannel.factory(self.opts, crypt="clear")
 
         sign_in_payload = self.minion_sign_in_payload()
         try:
@@ -1508,11 +1515,9 @@ class Crypticle:
         Serialize and encrypt a python object
         """
         if nonce:
-            toencrypt = (
-                self.PICKLE_PAD + nonce.encode() + salt.payload.Serial({}).dumps(obj)
-            )
+            toencrypt = self.PICKLE_PAD + nonce.encode() + salt.payload.dumps(obj)
         else:
-            toencrypt = self.PICKLE_PAD + salt.payload.Serial({}).dumps(obj)
+            toencrypt = self.PICKLE_PAD + salt.payload.dumps(obj)
         return self.encrypt(toencrypt)
 
     def loads(self, data, raw=False, nonce=None):
@@ -1529,7 +1534,7 @@ class Crypticle:
             data = data[32:]
             if ret_nonce != nonce:
                 raise SaltClientError("Nonce verification error")
-        payload = salt.payload.Serial({}).loads(data, raw=raw)
+        payload = salt.payload.loads(data, raw=raw)
         if isinstance(payload, dict):
             if "serial" in payload:
                 serial = payload.pop("serial")
