@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Amazon S3 Fileserver Backend
 
@@ -76,18 +75,26 @@ structure::
 
     More info here:
     https://docs.aws.amazon.com/cli/latest/topic/s3-config.html
+
+.. note:: This fileserver back-end will by default sync all buckets on every
+    fileserver update.
+
+    If you want files to be only populated in the cache when requested, you can
+    disable this in the master config:
+
+    .. code-block:: yaml
+
+        s3.s3_sync_on_update: False
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import datetime
 import logging
 import os
 import pickle
 import time
+import urllib.parse
 
-# Import salt libs
 import salt.fileserver as fs
 import salt.modules
 import salt.utils.files
@@ -95,18 +102,9 @@ import salt.utils.gzip_util
 import salt.utils.hashutils
 import salt.utils.versions
 
-# Import 3rd-party libs
-# pylint: disable=import-error,no-name-in-module,redefined-builtin
-from salt.ext import six
-from salt.ext.six.moves import filter
-from salt.ext.six.moves.urllib.parse import quote as _quote
-
-# pylint: enable=import-error,no-name-in-module,redefined-builtin
-
 log = logging.getLogger(__name__)
 
-S3_CACHE_EXPIRE = 30  # cache for 30 seconds
-S3_SYNC_ON_UPDATE = True  # sync cache on update rather than jit
+S3_HASH_TYPE = "md5"
 
 
 def envs():
@@ -127,17 +125,18 @@ def update():
 
     metadata = _init()
 
-    if S3_SYNC_ON_UPDATE:
+    # sync cache on update rather than jit
+    if __opts__.get("s3.s3_sync_on_update", True):
         # sync the buckets to the local cache
         log.info("Syncing local cache from S3...")
-        for saltenv, env_meta in six.iteritems(metadata):
+        for saltenv, env_meta in metadata.items():
             for bucket_files in _find_files(env_meta):
-                for bucket, files in six.iteritems(bucket_files):
+                for bucket, files in bucket_files.items():
                     for file_path in files:
                         cached_file_path = _get_cached_file_name(
                             bucket, saltenv, file_path
                         )
-                        log.info("%s - %s : %s", bucket, saltenv, file_path)
+                        log.debug("%s - %s : %s", bucket, saltenv, file_path)
 
                         # load the file from S3 if it's not in the cache or it's old
                         _get_file_from_s3(
@@ -170,7 +169,7 @@ def find_file(path, saltenv="base", **kwargs):
 
     # look for the files and check if they're ignored globally
     for bucket in env_files:
-        for bucket_name, files in six.iteritems(bucket):
+        for bucket_name, files in bucket.items():
             if path in files and not fs.is_file_ignored(__opts__, path):
                 fnd["bucket"] = bucket_name
                 fnd["path"] = path
@@ -192,7 +191,7 @@ def find_file(path, saltenv="base", **kwargs):
 
 def file_hash(load, fnd):
     """
-    Return an MD5 file hash
+    Return the hash of an object's cached copy
     """
     if "env" in load:
         # "env" is not supported; Use "saltenv".
@@ -211,8 +210,8 @@ def file_hash(load, fnd):
     )
 
     if os.path.isfile(cached_file_path):
-        ret["hsum"] = salt.utils.hashutils.get_hash(cached_file_path)
-        ret["hash_type"] = "md5"
+        ret["hash_type"] = S3_HASH_TYPE
+        ret["hsum"] = salt.utils.hashutils.get_hash(cached_file_path, S3_HASH_TYPE)
 
     return ret
 
@@ -245,7 +244,7 @@ def serve_file(load, fnd):
     with salt.utils.files.fopen(cached_file_path, "rb") as fp_:
         fp_.seek(load["loc"])
         data = fp_.read(__opts__["file_buffer_size"])
-        if data and six.PY3 and not salt.utils.files.is_binary(cached_file_path):
+        if data and not salt.utils.files.is_binary(cached_file_path):
             data = data.decode(__salt_system_encoding__)
         if gzip and data:
             data = salt.utils.gzip_util.compress(data, gzip)
@@ -273,7 +272,7 @@ def file_list(load):
     if not metadata or saltenv not in metadata:
         return ret
     for bucket in _find_files(metadata[saltenv]):
-        for buckets in six.itervalues(bucket):
+        for buckets in bucket.values():
             files = [f for f in buckets if not fs.is_file_ignored(__opts__, f)]
             ret += _trim_env_off_path(files, saltenv)
 
@@ -311,7 +310,7 @@ def dir_list(load):
 
     # grab all the dirs from the buckets cache file
     for bucket in _find_dirs(metadata[saltenv]):
-        for dirs in six.itervalues(bucket):
+        for dirs in bucket.values():
             # trim env and trailing slash
             dirs = _trim_env_off_path(dirs, saltenv, trim_slash=True)
             # remove empty string left by the base env dir in single bucket mode
@@ -354,7 +353,7 @@ def _init():
     specified and cache the data to disk.
     """
     cache_file = _get_buckets_cache_filename()
-    exp = time.time() - S3_CACHE_EXPIRE
+    exp = time.time() - __opts__.get("s3.s3_cache_expire", 30)
 
     # check mtime of the buckets files cache
     metadata = None
@@ -459,7 +458,7 @@ def _refresh_buckets_cache_file(cache_file):
 
     if _is_env_per_bucket():
         # Single environment per bucket
-        for saltenv, buckets in six.iteritems(_get_buckets()):
+        for saltenv, buckets in _get_buckets().items():
             bucket_files_list = []
             for bucket_name in buckets:
                 bucket_files = {}
@@ -499,7 +498,7 @@ def _refresh_buckets_cache_file(cache_file):
                             continue
                         else:
                             log.warning(
-                                "S3 Error! Do you have any files " "in your S3 bucket?"
+                                "S3 Error! Do you have any files in your S3 bucket?"
                             )
                             return {}
 
@@ -543,7 +542,7 @@ def _refresh_buckets_cache_file(cache_file):
                         continue
                     else:
                         log.warning(
-                            "S3 Error! Do you have any files " "in your S3 bucket?"
+                            "S3 Error! Do you have any files in your S3 bucket?"
                         )
                         return {}
 
@@ -603,7 +602,9 @@ def _read_buckets_cache_file(cache_file):
             ImportError,
             IndexError,
             KeyError,
-        ):
+            ValueError,
+        ) as exc:
+            log.debug("Exception reading buckets cache file: '%s'", exc)
             data = None
 
     return data
@@ -618,7 +619,7 @@ def _find_files(metadata):
     found = {}
 
     for bucket_dict in metadata:
-        for bucket_name, data in six.iteritems(bucket_dict):
+        for bucket_name, data in bucket_dict.items():
             filepaths = [k["Key"] for k in data]
             filepaths = [k for k in filepaths if not k.endswith("/")]
             if bucket_name not in found:
@@ -644,7 +645,7 @@ def _find_dirs(metadata):
     found = {}
 
     for bucket_dict in metadata:
-        for bucket_name, data in six.iteritems(bucket_dict):
+        for bucket_name, data in bucket_dict.items():
             dirpaths = set()
             for path in [k["Key"] for k in data]:
                 prefix = ""
@@ -717,11 +718,15 @@ def _get_file_from_s3(metadata, saltenv, bucket_name, path, cached_file_path):
 
             if file_etag.find("-") == -1:
                 file_md5 = file_etag
-                cached_md5 = salt.utils.hashutils.get_hash(cached_file_path, "md5")
+                cached_md5 = salt.utils.hashutils.get_hash(
+                    cached_file_path, S3_HASH_TYPE
+                )
 
                 # hashes match we have a cache hit
                 if cached_md5 == file_md5:
                     return
+                else:
+                    log.info(f"found different hash for file {path}, updating...")
             else:
                 cached_file_stat = os.stat(cached_file_path)
                 cached_file_size = cached_file_stat.st_size
@@ -750,7 +755,7 @@ def _get_file_from_s3(metadata, saltenv, bucket_name, path, cached_file_path):
                         service_url=service_url,
                         verify_ssl=verify_ssl,
                         location=location,
-                        path=_quote(path),
+                        path=urllib.parse.quote(path),
                         local_file=cached_file_path,
                         full_headers=True,
                         path_style=path_style,
@@ -760,11 +765,11 @@ def _get_file_from_s3(metadata, saltenv, bucket_name, path, cached_file_path):
                         for header_name, header_value in ret["headers"].items():
                             name = header_name.strip()
                             value = header_value.strip()
-                            if six.text_type(name).lower() == "last-modified":
+                            if str(name).lower() == "last-modified":
                                 s3_file_mtime = datetime.datetime.strptime(
                                     value, "%a, %d %b %Y %H:%M:%S %Z"
                                 )
-                            elif six.text_type(name).lower() == "content-length":
+                            elif str(name).lower() == "content-length":
                                 s3_file_size = int(value)
                         if (
                             cached_file_size == s3_file_size
@@ -788,7 +793,7 @@ def _get_file_from_s3(metadata, saltenv, bucket_name, path, cached_file_path):
         service_url=service_url,
         verify_ssl=verify_ssl,
         location=location,
-        path=_quote(path),
+        path=urllib.parse.quote(path),
         local_file=cached_file_path,
         path_style=path_style,
         https_enable=https_enable,
