@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
 """
-The matcher subsystem needs a function called 'confirm_top', which
+The matcher subsystem needs a function called "confirm_top", which
 takes the data passed to a top file environment and determines if that
 data matches this minion.
 """
-from __future__ import absolute_import
-
 import logging
 
 import salt.loader
@@ -19,9 +16,6 @@ def confirm_top(match, data, nodegroups=None):
     data matches this minion
     """
     matcher = "compound"
-    if not data:
-        log.error("Received bad data when setting the match from the top " "file")
-        return False
     for item in data:
         if isinstance(item, dict):
             if "match" in item:
@@ -35,4 +29,4 @@ def confirm_top(match, data, nodegroups=None):
         m = matchers[funcname]
         return m(match)
     # except TypeError, KeyError:
-    #     log.error('Attempting to match with unknown matcher: %s', matcher)
+    #     log.error("Attempting to match with unknown matcher: %s", matcher)
