@@ -40,31 +40,33 @@ def get_latest_snapshot(
     use_literal_group_id=False,
 ):
     """
-       Gets latest snapshot of the given artifact
+    Gets latest snapshot of the given artifact
 
-       artifactory_url
-           URL of artifactory instance
-       repository
-           Snapshot repository in artifactory to retrieve artifact from, for example: libs-snapshots
-       group_id
-           Group Id of the artifact
-       artifact_id
-           Artifact Id of the artifact
-       packaging
-           Packaging type (jar,war,ear,etc)
-       target_dir
-           Target directory to download artifact to (default: /tmp)
-       target_file
-           Target file to download artifact to (by default it is target_dir/artifact_id-snapshot_version.packaging)
-       classifier
-           Artifact classifier name (ex: sources,javadoc,etc). Optional parameter.
-       username
-           Artifactory username. Optional parameter.
-       password
-           Artifactory password. Optional parameter.
-       """
+    artifactory_url
+        URL of artifactory instance
+    repository
+        Snapshot repository in artifactory to retrieve artifact from, for example: libs-snapshots
+    group_id
+        Group Id of the artifact
+    artifact_id
+        Artifact Id of the artifact
+    packaging
+        Packaging type (jar,war,ear,etc)
+    target_dir
+        Target directory to download artifact to (default: /tmp)
+    target_file
+        Target file to download artifact to (by default it is target_dir/artifact_id-snapshot_version.packaging)
+    classifier
+        Artifact classifier name (ex: sources,javadoc,etc). Optional parameter.
+    username
+        Artifactory username. Optional parameter.
+    password
+        Artifactory password. Optional parameter.
+    """
     log.debug(
-        "======================== MODULE FUNCTION: artifactory.get_latest_snapshot, artifactory_url=%s, repository=%s, group_id=%s, artifact_id=%s, packaging=%s, target_dir=%s, classifier=%s)",
+        "======================== MODULE FUNCTION: artifactory.get_latest_snapshot,"
+        " artifactory_url=%s, repository=%s, group_id=%s, artifact_id=%s, packaging=%s,"
+        " target_dir=%s, classifier=%s)",
         artifactory_url,
         repository,
         group_id,
@@ -77,7 +79,7 @@ def get_latest_snapshot(
     headers = {}
     if username and password:
         headers["Authorization"] = "Basic {}".format(
-            salt.utils.hashutils.base64_encodestring(
+            salt.utils.hashutils.base64_b64encode(
                 "{}:{}".format(username.replace("\n", ""), password.replace("\n", ""))
             )
         )
@@ -122,33 +124,35 @@ def get_snapshot(
     use_literal_group_id=False,
 ):
     """
-       Gets snapshot of the desired version of the artifact
+    Gets snapshot of the desired version of the artifact
 
-       artifactory_url
-           URL of artifactory instance
-       repository
-           Snapshot repository in artifactory to retrieve artifact from, for example: libs-snapshots
-       group_id
-           Group Id of the artifact
-       artifact_id
-           Artifact Id of the artifact
-       packaging
-           Packaging type (jar,war,ear,etc)
-       version
-           Version of the artifact
-       target_dir
-           Target directory to download artifact to (default: /tmp)
-       target_file
-           Target file to download artifact to (by default it is target_dir/artifact_id-snapshot_version.packaging)
-       classifier
-           Artifact classifier name (ex: sources,javadoc,etc). Optional parameter.
-       username
-           Artifactory username. Optional parameter.
-       password
-           Artifactory password. Optional parameter.
-       """
+    artifactory_url
+        URL of artifactory instance
+    repository
+        Snapshot repository in artifactory to retrieve artifact from, for example: libs-snapshots
+    group_id
+        Group Id of the artifact
+    artifact_id
+        Artifact Id of the artifact
+    packaging
+        Packaging type (jar,war,ear,etc)
+    version
+        Version of the artifact
+    target_dir
+        Target directory to download artifact to (default: /tmp)
+    target_file
+        Target file to download artifact to (by default it is target_dir/artifact_id-snapshot_version.packaging)
+    classifier
+        Artifact classifier name (ex: sources,javadoc,etc). Optional parameter.
+    username
+        Artifactory username. Optional parameter.
+    password
+        Artifactory password. Optional parameter.
+    """
     log.debug(
-        "======================== MODULE FUNCTION: artifactory.get_snapshot(artifactory_url=%s, repository=%s, group_id=%s, artifact_id=%s, packaging=%s, version=%s, target_dir=%s, classifier=%s)",
+        "======================== MODULE FUNCTION:"
+        " artifactory.get_snapshot(artifactory_url=%s, repository=%s, group_id=%s,"
+        " artifact_id=%s, packaging=%s, version=%s, target_dir=%s, classifier=%s)",
         artifactory_url,
         repository,
         group_id,
@@ -161,7 +165,7 @@ def get_snapshot(
     headers = {}
     if username and password:
         headers["Authorization"] = "Basic {}".format(
-            salt.utils.hashutils.base64_encodestring(
+            salt.utils.hashutils.base64_b64encode(
                 "{}:{}".format(username.replace("\n", ""), password.replace("\n", ""))
             )
         )
@@ -196,31 +200,33 @@ def get_latest_release(
     use_literal_group_id=False,
 ):
     """
-       Gets the latest release of the artifact
+    Gets the latest release of the artifact
 
-       artifactory_url
-           URL of artifactory instance
-       repository
-           Release repository in artifactory to retrieve artifact from, for example: libs-releases
-       group_id
-           Group Id of the artifact
-       artifact_id
-           Artifact Id of the artifact
-       packaging
-           Packaging type (jar,war,ear,etc)
-       target_dir
-           Target directory to download artifact to (default: /tmp)
-       target_file
-           Target file to download artifact to (by default it is target_dir/artifact_id-version.packaging)
-       classifier
-           Artifact classifier name (ex: sources,javadoc,etc). Optional parameter.
-       username
-           Artifactory username. Optional parameter.
-       password
-           Artifactory password. Optional parameter.
-       """
+    artifactory_url
+        URL of artifactory instance
+    repository
+        Release repository in artifactory to retrieve artifact from, for example: libs-releases
+    group_id
+        Group Id of the artifact
+    artifact_id
+        Artifact Id of the artifact
+    packaging
+        Packaging type (jar,war,ear,etc)
+    target_dir
+        Target directory to download artifact to (default: /tmp)
+    target_file
+        Target file to download artifact to (by default it is target_dir/artifact_id-version.packaging)
+    classifier
+        Artifact classifier name (ex: sources,javadoc,etc). Optional parameter.
+    username
+        Artifactory username. Optional parameter.
+    password
+        Artifactory password. Optional parameter.
+    """
     log.debug(
-        "======================== MODULE FUNCTION: artifactory.get_latest_release(artifactory_url=%s, repository=%s, group_id=%s, artifact_id=%s, packaging=%s, target_dir=%s, classifier=%s)",
+        "======================== MODULE FUNCTION:"
+        " artifactory.get_latest_release(artifactory_url=%s, repository=%s,"
+        " group_id=%s, artifact_id=%s, packaging=%s, target_dir=%s, classifier=%s)",
         artifactory_url,
         repository,
         group_id,
@@ -232,7 +238,7 @@ def get_latest_release(
     headers = {}
     if username and password:
         headers["Authorization"] = "Basic {}".format(
-            salt.utils.hashutils.base64_encodestring(
+            salt.utils.hashutils.base64_b64encode(
                 "{}:{}".format(username.replace("\n", ""), password.replace("\n", ""))
             )
         )
@@ -273,33 +279,35 @@ def get_release(
     use_literal_group_id=False,
 ):
     """
-       Gets the specified release of the artifact
+    Gets the specified release of the artifact
 
-       artifactory_url
-           URL of artifactory instance
-       repository
-           Release repository in artifactory to retrieve artifact from, for example: libs-releases
-       group_id
-           Group Id of the artifact
-       artifact_id
-           Artifact Id of the artifact
-       packaging
-           Packaging type (jar,war,ear,etc)
-       version
-           Version of the artifact
-       target_dir
-           Target directory to download artifact to (default: /tmp)
-       target_file
-           Target file to download artifact to (by default it is target_dir/artifact_id-version.packaging)
-       classifier
-           Artifact classifier name (ex: sources,javadoc,etc). Optional parameter.
-       username
-           Artifactory username. Optional parameter.
-       password
-           Artifactory password. Optional parameter.
-       """
+    artifactory_url
+        URL of artifactory instance
+    repository
+        Release repository in artifactory to retrieve artifact from, for example: libs-releases
+    group_id
+        Group Id of the artifact
+    artifact_id
+        Artifact Id of the artifact
+    packaging
+        Packaging type (jar,war,ear,etc)
+    version
+        Version of the artifact
+    target_dir
+        Target directory to download artifact to (default: /tmp)
+    target_file
+        Target file to download artifact to (by default it is target_dir/artifact_id-version.packaging)
+    classifier
+        Artifact classifier name (ex: sources,javadoc,etc). Optional parameter.
+    username
+        Artifactory username. Optional parameter.
+    password
+        Artifactory password. Optional parameter.
+    """
     log.debug(
-        "======================== MODULE FUNCTION: artifactory.get_release(artifactory_url=%s, repository=%s, group_id=%s, artifact_id=%s, packaging=%s, version=%s, target_dir=%s, classifier=%s)",
+        "======================== MODULE FUNCTION:"
+        " artifactory.get_release(artifactory_url=%s, repository=%s, group_id=%s,"
+        " artifact_id=%s, packaging=%s, version=%s, target_dir=%s, classifier=%s)",
         artifactory_url,
         repository,
         group_id,
@@ -312,8 +320,9 @@ def get_release(
     headers = {}
     if username and password:
         headers["Authorization"] = "Basic {}".format(
-            salt.utils.hashutils.base64_encodestring(
+            salt.utils.hashutils.base64_b64encode(
                 "{}:{}".format(username.replace("\n", ""), password.replace("\n", ""))
+                ## f"{username.replace("\n", "")}:{password.replace("\n", "")}")
             )
         )
     release_url, file_name = _get_release_url(
@@ -705,8 +714,8 @@ def __save_artifact(artifact_url, target_file, headers):
                 return result
             else:
                 result["comment"] = (
-                    "File {} already exists, checksum does not match with Artifactory!\n"
-                    "Checksum URL: {}".format(target_file, checksum_url)
+                    "File {} already exists, checksum does not match with"
+                    " Artifactory!\nChecksum URL: {}".format(target_file, checksum_url)
                 )
 
         else:
@@ -723,7 +732,7 @@ def __save_artifact(artifact_url, target_file, headers):
             local_file.write(salt.utils.stringutils.to_bytes(f.read()))
         result["status"] = True
         result["comment"] = __append_comment(
-            ("Artifact downloaded from URL: {}".format(artifact_url)),
+            "Artifact downloaded from URL: {}".format(artifact_url),
             result["comment"],
         )
         result["changes"]["downloaded_file"] = target_file
@@ -769,8 +778,8 @@ def __get_error_comment(http_error, request_url):
         comment = "HTTP Error 404. Request URL: " + request_url
     elif http_error.code == http.client.CONFLICT:
         comment = (
-            "HTTP Error 409: Conflict. Requested URL: {}. \n"
-            "This error may be caused by reading snapshot artifact from non-snapshot repository.".format(
+            "HTTP Error 409: Conflict. Requested URL: {}. \nThis error may be caused by"
+            " reading snapshot artifact from non-snapshot repository.".format(
                 request_url
             )
         )
