@@ -39,6 +39,7 @@ Connection module for Amazon IAM
 
 import logging
 import time
+import urllib.parse
 
 import salt.utils.compat
 import salt.utils.json
@@ -46,12 +47,10 @@ import salt.utils.odict as odict
 import salt.utils.versions
 
 # pylint: disable=unused-import
-from salt.ext.six.moves.urllib.parse import unquote as _unquote
-
 try:
     import boto
-    import boto.iam
     import boto3
+    import boto.iam
     import botocore
 
     logging.getLogger("boto").setLevel(logging.CRITICAL)
@@ -182,7 +181,7 @@ def describe_role(name, region=None, key=None, keyid=None, profile=None):
             return False
         role = info.get_role_response.get_role_result.role
         role["assume_role_policy_document"] = salt.utils.json.loads(
-            _unquote(role.assume_role_policy_document)
+            urllib.parse.unquote(role.assume_role_policy_document)
         )
         # If Sid wasn't defined by the user, boto will still return a Sid in
         # each policy. To properly check idempotently, let's remove the Sid
@@ -579,7 +578,7 @@ def delete_group_policy(
     """
     Delete a group policy.
 
-    CLI Example::
+    CLI Example:
 
     .. code-block:: bash
 
@@ -626,7 +625,7 @@ def get_group_policy(
         if not info:
             return False
         info = info.get_group_policy_response.get_group_policy_result.policy_document
-        info = _unquote(info)
+        info = urllib.parse.unquote(info)
         info = salt.utils.json.loads(info, object_pairs_hook=odict.OrderedDict)
         return info
     except boto.exception.BotoServerError as e:
@@ -643,6 +642,8 @@ def get_all_groups(path_prefix="/", region=None, key=None, keyid=None, profile=N
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt-call boto_iam.get_all_groups
     """
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
@@ -670,6 +671,8 @@ def get_all_instance_profiles(
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt-call boto_iam.get_all_instance_profiles
     """
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
@@ -694,6 +697,8 @@ def list_instance_profiles(
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt-call boto_iam.list_instance_profiles
     """
     p = get_all_instance_profiles(path_prefix, region, key, keyid, profile)
@@ -726,7 +731,7 @@ def delete_group(group_name, region=None, key=None, keyid=None, profile=None):
     """
     Delete a group policy.
 
-    CLI Example::
+    CLI Example:
 
     .. code-block:: bash
 
@@ -1187,7 +1192,7 @@ def get_role_policy(
         # I _hate_ you for not giving me an object boto.
         _policy = _policy.get_role_policy_response.policy_document
         # Policy is url encoded
-        _policy = _unquote(_policy)
+        _policy = urllib.parse.unquote(_policy)
         _policy = salt.utils.json.loads(_policy, object_pairs_hook=odict.OrderedDict)
         return _policy
     except boto.exception.BotoServerError:
@@ -1375,6 +1380,8 @@ def get_all_roles(path_prefix=None, region=None, key=None, keyid=None, profile=N
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt-call boto_iam.get_all_roles
     """
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
@@ -1398,6 +1405,8 @@ def get_all_users(path_prefix="/", region=None, key=None, keyid=None, profile=No
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt-call boto_iam.get_all_users
     """
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
@@ -1467,7 +1476,7 @@ def get_user_policy(
         if not info:
             return False
         info = info.get_user_policy_response.get_user_policy_result.policy_document
-        info = _unquote(info)
+        info = urllib.parse.unquote(info)
         info = salt.utils.json.loads(info, object_pairs_hook=odict.OrderedDict)
         return info
     except boto.exception.BotoServerError as e:
@@ -1641,6 +1650,8 @@ def export_users(path_prefix="/", region=None, key=None, keyid=None, profile=Non
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt-call boto_iam.export_users --out=txt | sed "s/local: //" > iam_users.sls
     """
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
@@ -1658,7 +1669,7 @@ def export_users(path_prefix="/", region=None, key=None, keyid=None, profile=Non
         for policy_name in _policies:
             _policy = conn.get_user_policy(name, policy_name)
             _policy = salt.utils.json.loads(
-                _unquote(
+                urllib.parse.unquote(
                     _policy.get_user_policy_response.get_user_policy_result.policy_document
                 )
             )
@@ -1678,6 +1689,8 @@ def export_roles(path_prefix="/", region=None, key=None, keyid=None, profile=Non
 
     CLI Example:
 
+    .. code-block:: bash
+
         salt-call boto_iam.export_roles --out=txt | sed "s/local: //" > iam_roles.sls
     """
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
@@ -1695,7 +1708,7 @@ def export_roles(path_prefix="/", region=None, key=None, keyid=None, profile=Non
         for policy_name in _policies:
             _policy = conn.get_role_policy(name, policy_name)
             _policy = salt.utils.json.loads(
-                _unquote(
+                urllib.parse.unquote(
                     _policy.get_role_policy_response.get_role_policy_result.policy_document
                 )
             )
@@ -1706,7 +1719,7 @@ def export_roles(path_prefix="/", region=None, key=None, keyid=None, profile=Non
         role_sls.append(
             {
                 "policy_document": salt.utils.json.loads(
-                    _unquote(role.assume_role_policy_document)
+                    urllib.parse.unquote(role.assume_role_policy_document)
                 )
             }
         )
@@ -1910,7 +1923,7 @@ def get_policy_version(
             .get("get_policy_version_result", {})
             .get("policy_version", {})
         )
-        retval["document"] = _unquote(retval.get("document"))
+        retval["document"] = urllib.parse.unquote(retval.get("document"))
         return {"policy_version": retval}
     except boto.exception.BotoServerError:
         return None
