@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Glance module for interacting with OpenStack Glance
 
@@ -26,7 +25,6 @@ Example configuration
       identity_api_version: 3
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
 
 HAS_SHADE = False
 try:
@@ -47,7 +45,8 @@ def __virtual__():
         return __virtualname__
     return (
         False,
-        "The glanceng execution module failed to load: shade python module is not available",
+        "The glanceng execution module failed to load: shade python module is not"
+        " available",
     )
 
 
