@@ -1,29 +1,21 @@
-# encoding: utf-8
-'''
+"""
 A collection of hashing and encoding functions
-'''
+"""
+
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 import base64
 import hashlib
 import hmac
+import io
 
-# Import Salt libs
 import salt.exceptions
-from salt.ext import six
 import salt.utils.files
 import salt.utils.hashutils
 import salt.utils.stringutils
 
-if six.PY2:
-    import StringIO
-elif six.PY3:
-    from io import StringIO
 
-
-def digest(instr, checksum='md5'):
-    '''
+def digest(instr, checksum="md5"):
+    """
     Return a checksum digest for a string
 
     instr
@@ -37,23 +29,24 @@ def digest(instr, checksum='md5'):
     .. code-block:: bash
 
         salt '*' hashutil.digest 'get salted'
-    '''
+    """
     hashing_funcs = {
-        'md5': __salt__['hashutil.md5_digest'],
-        'sha256': __salt__['hashutil.sha256_digest'],
-        'sha512': __salt__['hashutil.sha512_digest'],
+        "md5": __salt__["hashutil.md5_digest"],
+        "sha256": __salt__["hashutil.sha256_digest"],
+        "sha512": __salt__["hashutil.sha512_digest"],
     }
     hash_func = hashing_funcs.get(checksum)
 
     if hash_func is None:
         raise salt.exceptions.CommandExecutionError(
-                "Hash func '{0}' is not supported.".format(checksum))
+            "Hash func '{}' is not supported.".format(checksum)
+        )
 
     return hash_func(instr)
 
 
-def digest_file(infile, checksum='md5'):
-    '''
+def digest_file(infile, checksum="md5"):
+    """
     Return a checksum digest for a file
 
     infile
@@ -68,19 +61,20 @@ def digest_file(infile, checksum='md5'):
     .. code-block:: bash
 
         salt '*' hashutil.digest_file /path/to/file
-    '''
-    if not __salt__['file.file_exists'](infile):
+    """
+    if not __salt__["file.file_exists"](infile):
         raise salt.exceptions.CommandExecutionError(
-                "File path '{0}' not found.".format(infile))
+            "File path '{}' not found.".format(infile)
+        )
 
-    with salt.utils.files.fopen(infile, 'rb') as f:
-        file_hash = __salt__['hashutil.digest'](f.read(), checksum)
+    with salt.utils.files.fopen(infile, "rb") as f:
+        file_hash = __salt__["hashutil.digest"](f.read(), checksum)
 
     return file_hash
 
 
 def base64_b64encode(instr):
-    '''
+    """
     Encode a string as base64 using the "modern" Python interface.
 
     Among other possible differences, the "modern" encoder does not include
@@ -93,12 +87,12 @@ def base64_b64encode(instr):
     .. code-block:: bash
 
         salt '*' hashutil.base64_b64encode 'get salted'
-    '''
+    """
     return salt.utils.hashutils.base64_b64encode(instr)
 
 
 def base64_b64decode(instr):
-    '''
+    """
     Decode a base64-encoded string using the "modern" Python interface
 
     .. versionadded:: 2016.3.0
@@ -108,31 +102,31 @@ def base64_b64decode(instr):
     .. code-block:: bash
 
         salt '*' hashutil.base64_b64decode 'Z2V0IHNhbHRlZA=='
-    '''
+    """
     return salt.utils.hashutils.base64_b64decode(instr)
 
 
 def base64_encodestring(instr):
-    '''
-    Encode a string as base64 using the "legacy" Python interface.
+    """
+    Encode a byte-like object as base64 using the "modern" Python interface.
 
-    Among other possible differences, the "legacy" encoder includes
+    Among other possible differences, the "modern" encoder includes
     a newline ('\\n') character after every 76 characters and always
-    at the end of the encoded string.
+    at the end of the encoded byte-like object.
 
-    .. versionadded:: 2014.7.0
+    .. versionadded:: 3000
 
     CLI Example:
 
     .. code-block:: bash
 
         salt '*' hashutil.base64_encodestring 'get salted'
-    '''
+    """
     return salt.utils.hashutils.base64_encodestring(instr)
 
 
 def base64_encodefile(fname):
-    '''
+    """
     Read a file from the file system and return as a base64 encoded string
 
     .. versionadded:: 2016.3.0
@@ -154,21 +148,21 @@ def base64_encodefile(fname):
     .. code-block:: bash
 
         salt '*' hashutil.base64_encodefile /path/to/binary_file
-    '''
-    encoded_f = StringIO.StringIO()
+    """
+    encoded_f = io.BytesIO()
 
-    with salt.utils.files.fopen(fname, 'rb') as f:
+    with salt.utils.files.fopen(fname, "rb") as f:
         base64.encode(f, encoded_f)
 
     encoded_f.seek(0)
-    return encoded_f.read()
+    return salt.utils.stringutils.to_str(encoded_f.read())
 
 
 def base64_decodestring(instr):
-    '''
-    Decode a base64-encoded string using the "legacy" Python interface
+    """
+    Decode a base64-encoded byte-like object using the "modern" Python interface
 
-    .. versionadded:: 2014.7.0
+    .. versionadded:: 3000
 
     CLI Example:
 
@@ -176,12 +170,12 @@ def base64_decodestring(instr):
 
         salt '*' hashutil.base64_decodestring instr='Z2V0IHNhbHRlZAo='
 
-    '''
+    """
     return salt.utils.hashutils.base64_decodestring(instr)
 
 
 def base64_decodefile(instr, outfile):
-    r'''
+    r"""
     Decode a base64-encoded string and write the result to a file
 
     .. versionadded:: 2016.3.0
@@ -191,17 +185,17 @@ def base64_decodefile(instr, outfile):
     .. code-block:: bash
 
         salt '*' hashutil.base64_decodefile instr='Z2V0IHNhbHRlZAo=' outfile='/path/to/binary_file'
-    '''
-    encoded_f = StringIO.StringIO(instr)
+    """
+    encoded_f = io.StringIO(instr)
 
-    with salt.utils.files.fopen(outfile, 'wb') as f:
+    with salt.utils.files.fopen(outfile, "wb") as f:
         base64.decode(encoded_f, f)
 
     return True
 
 
 def md5_digest(instr):
-    '''
+    """
     Generate an md5 hash of a given string
 
     .. versionadded:: 2014.7.0
@@ -211,12 +205,12 @@ def md5_digest(instr):
     .. code-block:: bash
 
         salt '*' hashutil.md5_digest 'get salted'
-    '''
+    """
     return salt.utils.hashutils.md5_digest(instr)
 
 
 def sha256_digest(instr):
-    '''
+    """
     Generate an sha256 hash of a given string
 
     .. versionadded:: 2014.7.0
@@ -226,12 +220,12 @@ def sha256_digest(instr):
     .. code-block:: bash
 
         salt '*' hashutil.sha256_digest 'get salted'
-    '''
+    """
     return salt.utils.hashutils.sha256_digest(instr)
 
 
 def sha512_digest(instr):
-    '''
+    """
     Generate an sha512 hash of a given string
 
     .. versionadded:: 2014.7.0
@@ -241,12 +235,12 @@ def sha512_digest(instr):
     .. code-block:: bash
 
         salt '*' hashutil.sha512_digest 'get salted'
-    '''
+    """
     return salt.utils.hashutils.sha512_digest(instr)
 
 
 def hmac_signature(string, shared_secret, challenge_hmac):
-    '''
+    """
     Verify a challenging hmac signature against a string / shared-secret
 
     .. versionadded:: 2014.7.0
@@ -258,12 +252,27 @@ def hmac_signature(string, shared_secret, challenge_hmac):
     .. code-block:: bash
 
         salt '*' hashutil.hmac_signature 'get salted' 'shared secret' 'eBWf9bstXg+NiP5AOwppB5HMvZiYMPzEM9W5YMm/AmQ='
-    '''
+    """
     return salt.utils.hashutils.hmac_signature(string, shared_secret, challenge_hmac)
 
 
+def hmac_compute(string, shared_secret):
+    """
+    .. versionadded:: 3000
+
+    Compute a HMAC SHA256 digest using a string and secret.
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' hashutil.hmac_compute 'get salted' 'shared secret'
+    """
+    return salt.utils.hashutils.hmac_compute(string, shared_secret)
+
+
 def github_signature(string, shared_secret, challenge_hmac):
-    '''
+    """
     Verify a challenging hmac signature against a string / shared-secret for
     github webhooks.
 
@@ -276,12 +285,13 @@ def github_signature(string, shared_secret, challenge_hmac):
     .. code-block:: bash
 
         salt '*' hashutil.github_signature '{"ref":....} ' 'shared secret' 'sha1=bc6550fc290acf5b42283fa8deaf55cea0f8c206'
-    '''
+    """
     msg = string
     key = shared_secret
-    hashtype, challenge = challenge_hmac.split('=')
-    if six.text_type:
+    hashtype, challenge = challenge_hmac.split("=")
+    if isinstance(msg, str):
         msg = salt.utils.stringutils.to_bytes(msg)
+    if isinstance(key, str):
         key = salt.utils.stringutils.to_bytes(key)
     hmac_hash = hmac.new(key, msg, getattr(hashlib, hashtype))
-    return hmac_hash.hexdigest() == challenge
+    return hmac.compare_digest(hmac_hash.hexdigest(), challenge)
