@@ -1,48 +1,47 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Run nagios plugins/checks from salt and get the return as data.
-'''
+"""
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
+
+import logging
 import os
 import stat
-import logging
-
-# Import 3rd-party libs
-from salt.ext import six
 
 log = logging.getLogger(__name__)
 
-PLUGINDIR = '/usr/lib/nagios/plugins/'
+PLUGINDIR = "/usr/lib/nagios/plugins/"
 
 
 def __virtual__():
-    '''
+    """
     Only load if nagios-plugins are installed
-    '''
+    """
     if os.path.isdir(PLUGINDIR):
-        return 'nagios'
-    return (False, 'The nagios execution module cannot be loaded: nagios-plugins are not installed.')
+        return "nagios"
+    return (
+        False,
+        "The nagios execution module cannot be loaded: nagios-plugins are not"
+        " installed.",
+    )
 
 
-def _execute_cmd(plugin, args='', run_type='cmd.retcode'):
-    '''
+def _execute_cmd(plugin, args="", run_type="cmd.retcode"):
+    """
     Execute nagios plugin if it's in the directory with salt command specified in run_type
-    '''
+    """
     data = {}
 
     all_plugins = list_plugins()
     if plugin in all_plugins:
         data = __salt__[run_type](
-                '{0}{1} {2}'.format(PLUGINDIR, plugin, args),
-                python_shell=False)
+            "{}{} {}".format(PLUGINDIR, plugin, args), python_shell=False
+        )
 
     return data
 
 
 def _execute_pillar(pillar_name, run_type):
-    '''
+    """
     Run one or more nagios plugins from pillar data and get the result of run_type
     The pillar have to be in this format:
     ------
@@ -55,8 +54,8 @@ def _execute_pillar(pillar_name, run_type):
         APT:
             - check_apt
     -------
-    '''
-    groups = __salt__['pillar.get'](pillar_name)
+    """
+    groups = __salt__["pillar.get"](pillar_name)
 
     data = {}
     for group in groups:
@@ -66,11 +65,11 @@ def _execute_pillar(pillar_name, run_type):
             # Check if is a dict to get the arguments
             # in command if not set the arguments to empty string
             if isinstance(command, dict):
-                plugin = next(six.iterkeys(command))
+                plugin = next(iter(command.keys()))
                 args = command[plugin]
             else:
                 plugin = command
-                args = ''
+                args = ""
             command_key = _format_dict_key(args, plugin)
             data[group][command_key] = run_type(plugin, args)
     return data
@@ -78,16 +77,16 @@ def _execute_pillar(pillar_name, run_type):
 
 def _format_dict_key(args, plugin):
     key_name = plugin
-    args_key = args.replace(' ', '')
-    if args != '':
-        args_key = '_' + args_key
+    args_key = args.replace(" ", "")
+    if args != "":
+        args_key = "_" + args_key
         key_name = plugin + args_key
 
     return key_name
 
 
-def run(plugin, args=''):
-    '''
+def run(plugin, args=""):
+    """
     Run nagios plugin and return all the data execution with cmd.run
 
     CLI Example:
@@ -96,16 +95,16 @@ def run(plugin, args=''):
 
         salt '*' nagios.run check_apt
         salt '*' nagios.run check_icmp '8.8.8.8'
-    '''
-    data = _execute_cmd(plugin, args, 'cmd.run')
+    """
+    data = _execute_cmd(plugin, args, "cmd.run")
 
     return data
 
 
-def retcode(plugin, args='', key_name=None):
-    '''
+def retcode(plugin, args="", key_name=None):
+    """
     Run one nagios plugin and return retcode of the execution
-    '''
+    """
     data = {}
 
     # Remove all the spaces, the key must not have any space
@@ -114,22 +113,22 @@ def retcode(plugin, args='', key_name=None):
 
     data[key_name] = {}
 
-    status = _execute_cmd(plugin, args, 'cmd.retcode')
-    data[key_name]['status'] = status
+    status = _execute_cmd(plugin, args, "cmd.retcode")
+    data[key_name]["status"] = status
 
     return data
 
 
-def run_all(plugin, args=''):
-    '''
+def run_all(plugin, args=""):
+    """
     Run nagios plugin and return all the data execution with cmd.run_all
-    '''
-    data = _execute_cmd(plugin, args, 'cmd.run_all')
+    """
+    data = _execute_cmd(plugin, args, "cmd.run_all")
     return data
 
 
 def retcode_pillar(pillar_name):
-    '''
+    """
     Run one or more nagios plugins from pillar data and get the result of cmd.retcode
     The pillar have to be in this format::
 
@@ -155,8 +154,8 @@ def retcode_pillar(pillar_name):
     .. code-block:: bash
 
         salt '*' nagios.retcode webserver
-    '''
-    groups = __salt__['pillar.get'](pillar_name)
+    """
+    groups = __salt__["pillar.get"](pillar_name)
 
     check = {}
     data = {}
@@ -167,30 +166,30 @@ def retcode_pillar(pillar_name):
             # Check if is a dict to get the arguments
             # in command if not set the arguments to empty string
             if isinstance(command, dict):
-                plugin = next(six.iterkeys(command))
+                plugin = next(iter(command.keys()))
                 args = command[plugin]
             else:
                 plugin = command
-                args = ''
+                args = ""
 
             check.update(retcode(plugin, args, group))
 
             current_value = 0
-            new_value = int(check[group]['status'])
+            new_value = int(check[group]["status"])
             if group in data:
-                current_value = int(data[group]['status'])
+                current_value = int(data[group]["status"])
 
             if (new_value > current_value) or (group not in data):
 
                 if group not in data:
                     data[group] = {}
-                data[group]['status'] = new_value
+                data[group]["status"] = new_value
 
     return data
 
 
 def run_pillar(pillar_name):
-    '''
+    """
     Run one or more nagios plugins from pillar data and get the result of cmd.run
     The pillar have to be in this format::
 
@@ -215,14 +214,14 @@ def run_pillar(pillar_name):
     .. code-block:: bash
 
         salt '*' nagios.run webserver
-    '''
+    """
     data = _execute_pillar(pillar_name, run)
 
     return data
 
 
 def run_all_pillar(pillar_name):
-    '''
+    """
     Run one or more nagios plugins from pillar data and get the result of cmd.run_all
     The pillar have to be in this format::
 
@@ -247,13 +246,13 @@ def run_all_pillar(pillar_name):
     .. code-block:: bash
 
         salt '*' nagios.run webserver
-    '''
+    """
     data = _execute_pillar(pillar_name, run_all)
     return data
 
 
 def list_plugins():
-    '''
+    """
     List all the nagios plugins
 
     CLI Example:
@@ -261,7 +260,7 @@ def list_plugins():
     .. code-block:: bash
 
         salt '*' nagios.list_plugins
-    '''
+    """
     plugin_list = os.listdir(PLUGINDIR)
     ret = []
     for plugin in plugin_list:
