@@ -12,16 +12,11 @@ import binascii
 import hashlib
 import logging
 import re
+import shlex
 
 import salt.modules.cmdmod
 import salt.utils.path
 
-try:
-    from shlex import quote as _quote_args  # pylint: disable=e0611
-except ImportError:
-    from pipes import quote as _quote_args
-
-
 log = logging.getLogger(__name__)
 
 # Define the module's virtual name
@@ -103,19 +98,22 @@ def list_users(verbose=True, hashes=False):
             log.error(res["stderr"] if "stderr" in res else res["stdout"])
             return users
 
-        user_data = {}
-        for user in res["stdout"].splitlines():
-            if user.startswith("-"):
-                if "unix username" in user_data:
-                    users[user_data["unix username"]] = user_data
-                user_data = {}
-            elif ":" in user:
-                label = user[: user.index(":")].strip().lower()
-                data = user[(user.index(":") + 1) :].strip()
-                user_data[label] = data
-
-        if user_data:
-            users[user_data["unix username"]] = user_data
+        for batch in re.split("\n-+|-+\n", res["stdout"]):
+            user_data = {}
+            last_label = None
+            for line in batch.splitlines():
+                if not line.strip():
+                    continue
+                label, sep, data = line.partition(":")
+                label = label.strip().lower()
+                data = data.strip()
+                if not sep:
+                    user_data[last_label] += line.strip()
+                else:
+                    last_label = label
+                    user_data[label] = data
+            if user_data:
+                users[user_data["unix username"]] = user_data
     else:
         # list users
         res = __salt__["cmd.run_all"]("pdbedit --list")
@@ -167,7 +165,7 @@ def delete(login):
     """
     if login in list_users(False):
         res = __salt__["cmd.run_all"](
-            "pdbedit --delete {login}".format(login=_quote_args(login)),
+            "pdbedit --delete {login}".format(login=shlex.quote(login)),
         )
 
         if res["retcode"] > 0:
@@ -205,14 +203,14 @@ def create(login, password, password_hashed=False, machine_account=False):
         password_hash = password.upper()
         password = ""  # wipe password
     else:
-        password_hash = generate_nt_hash(password)
+        password_hash = generate_nt_hash(password).decode("ascii")
 
     # create user
     if login not in list_users(False):
         # NOTE: --create requires a password, even if blank
         res = __salt__["cmd.run_all"](
             cmd="pdbedit --create --user {login} -t {machine}".format(
-                login=_quote_args(login),
+                login=shlex.quote(login),
                 machine="--machine" if machine_account else "",
             ),
             stdin="{password}\n{password}\n".format(password=password),
@@ -228,7 +226,7 @@ def create(login, password, password_hashed=False, machine_account=False):
     if user["nt hash"] != password_hash:
         res = __salt__["cmd.run_all"](
             "pdbedit --modify --user {login} --set-nt-hash={nthash}".format(
-                login=_quote_args(login), nthash=_quote_args(password_hash)
+                login=shlex.quote(login), nthash=shlex.quote(password_hash)
             ),
         )
 
@@ -369,9 +367,8 @@ def modify(
                 for f in val.upper():
                     if f not in ["N", "D", "H", "L", "X"]:
                         log.warning(
-                            "pdbedit.modify - unknown {f} flag for account_control, ignored".format(
-                                f=f
-                            )
+                            "pdbedit.modify - unknown %s flag for account_control, ignored",
+                            f,
                         )
                     else:
                         new.append(f)
@@ -386,7 +383,8 @@ def modify(
         for change in changes:
             cmds.append(
                 "{flag}{value}".format(
-                    flag=flags[change], value=_quote_args(changes[change]),
+                    flag=flags[change],
+                    value=shlex.quote(changes[change]),
                 )
             )
         if reset_login_hours:
@@ -396,7 +394,8 @@ def modify(
 
         res = __salt__["cmd.run_all"](
             "pdbedit --modify --user {login} {changes}".format(
-                login=_quote_args(login), changes=" ".join(cmds),
+                login=shlex.quote(login),
+                changes=" ".join(cmds),
             ),
         )
 
@@ -407,6 +406,3 @@ def modify(
             ret = "updated"
 
     return {login: ret}
-
-
-# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
