@@ -14,7 +14,7 @@ import salt.utils.dictupdate
 import salt.utils.functools
 import salt.utils.odict
 import salt.utils.yaml
-from salt.defaults import DEFAULT_TARGET_DELIM
+from salt.defaults import DEFAULT_TARGET_DELIM, NOT_SET
 from salt.exceptions import CommandExecutionError
 
 __proxyenabled__ = ["*"]
@@ -24,7 +24,7 @@ log = logging.getLogger(__name__)
 
 def get(
     key,
-    default=KeyError,
+    default=NOT_SET,
     merge=False,
     merge_nested_lists=None,
     delimiter=DEFAULT_TARGET_DELIM,
@@ -32,7 +32,7 @@ def get(
     saltenv=None,
 ):
     """
-    .. versionadded:: 0.14
+    .. versionadded:: 0.14.0
 
     Attempt to retrieve the named value from :ref:`in-memory pillar data
     <pillar-in-memory>`. If the pillar key is not present in the in-memory
@@ -122,6 +122,8 @@ def get(
         salt '*' pillar.get pkg:apache
         salt '*' pillar.get abc::def|ghi delimiter='|'
     """
+    if default == NOT_SET:
+        default = KeyError
     if not __opts__.get("pillar_raise_on_missing"):
         if default is KeyError:
             default = ""
@@ -296,7 +298,7 @@ def _obfuscate_inner(var):
         return "<{}>".format(var.__class__.__name__)
 
 
-def obfuscate(*args):
+def obfuscate(*args, **kwargs):
     """
     .. versionadded:: 2015.8.0
 
@@ -323,7 +325,7 @@ def obfuscate(*args):
         salt '*' pillar.obfuscate
 
     """
-    return _obfuscate_inner(items(*args))
+    return _obfuscate_inner(items(*args, **kwargs))
 
 
 # naming chosen for consistency with grains.ls, although it breaks the short
@@ -575,7 +577,7 @@ def file_exists(path, saltenv=None):
     pillar_roots = __opts__.get("pillar_roots")
     if not pillar_roots:
         raise CommandExecutionError(
-            "No pillar_roots found. Are you running " "this on the master?"
+            "No pillar_roots found. Are you running this on the master?"
         )
 
     if saltenv:
