@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manage users with the pw command
 
@@ -33,21 +32,15 @@ Manage users with the pw command
 # % pw usershow -n someuser
 # someuser:*:1001:1001::0:0:SomeUser Name:/home/someuser:/bin/sh
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import copy
 import logging
 
-# Import salt libs
 import salt.utils.args
 import salt.utils.data
 import salt.utils.user
 from salt.exceptions import CommandExecutionError
 
-# Import 3rd party libs
-from salt.ext import six
-
 try:
     import pwd
 
@@ -70,7 +63,8 @@ def __virtual__():
         return __virtualname__
     return (
         False,
-        "The pw_user execution module cannot be loaded: the pwd python module is not available or the system is not FreeBSD.",
+        "The pw_user execution module cannot be loaded: the pwd python module is not"
+        " available or the system is not FreeBSD.",
     )
 
 
@@ -81,7 +75,7 @@ def _get_gecos(name):
     try:
         gecos_field = pwd.getpwnam(name).pw_gecos.split(",", 3)
     except KeyError:
-        raise CommandExecutionError("User '{0}' does not exist".format(name))
+        raise CommandExecutionError("User '{}' does not exist".format(name))
     if not gecos_field:
         return {}
     else:
@@ -101,7 +95,7 @@ def _build_gecos(gecos_dict):
     Accepts a dictionary entry containing GECOS field names and their values,
     and returns a full GECOS comment string, to be used with pw usermod.
     """
-    return "{0},{1},{2},{3}".format(
+    return "{},{},{},{}".format(
         gecos_dict.get("fullname", ""),
         gecos_dict.get("roomnumber", ""),
         gecos_dict.get("workphone", ""),
@@ -113,8 +107,8 @@ def _update_gecos(name, key, value):
     """
     Common code to change a user's GECOS information
     """
-    if not isinstance(value, six.string_types):
-        value = six.text_type(value)
+    if not isinstance(value, str):
+        value = str(value)
     pre_info = _get_gecos(name)
     if not pre_info:
         return False
@@ -159,7 +153,7 @@ def add(
     if kwargs:
         log.warning("Invalid kwargs passed to user.add")
 
-    if isinstance(groups, six.string_types):
+    if isinstance(groups, str):
         groups = groups.split(",")
     cmd = ["pw", "useradd"]
     if uid:
@@ -203,7 +197,7 @@ def delete(name, remove=False, force=False):
     """
     if salt.utils.data.is_true(force):
         log.error(
-            "pw userdel does not support force-deleting user while " "user is logged in"
+            "pw userdel does not support force-deleting user while user is logged in"
         )
     cmd = ["pw", "userdel"]
     if remove:
@@ -244,7 +238,7 @@ def chuid(name, uid):
     """
     pre_info = info(name)
     if not pre_info:
-        raise CommandExecutionError("User '{0}' does not exist".format(name))
+        raise CommandExecutionError("User '{}' does not exist".format(name))
     if uid == pre_info["uid"]:
         return True
     cmd = ["pw", "usermod", "-u", uid, "-n", name]
@@ -264,7 +258,7 @@ def chgid(name, gid):
     """
     pre_info = info(name)
     if not pre_info:
-        raise CommandExecutionError("User '{0}' does not exist".format(name))
+        raise CommandExecutionError("User '{}' does not exist".format(name))
     if gid == pre_info["gid"]:
         return True
     cmd = ["pw", "usermod", "-g", gid, "-n", name]
@@ -284,7 +278,7 @@ def chshell(name, shell):
     """
     pre_info = info(name)
     if not pre_info:
-        raise CommandExecutionError("User '{0}' does not exist".format(name))
+        raise CommandExecutionError("User '{}' does not exist".format(name))
     if shell == pre_info["shell"]:
         return True
     cmd = ["pw", "usermod", "-s", shell, "-n", name]
@@ -315,7 +309,7 @@ def chhome(name, home, persist=False):
     """
     pre_info = info(name)
     if not pre_info:
-        raise CommandExecutionError("User '{0}' does not exist".format(name))
+        raise CommandExecutionError("User '{}' does not exist".format(name))
     if home == pre_info["home"]:
         return True
     cmd = ["pw", "usermod", name, "-d", home]
@@ -347,7 +341,7 @@ def chgroups(name, groups, append=False):
 
         salt '*' user.chgroups foo wheel,root True
     """
-    if isinstance(groups, six.string_types):
+    if isinstance(groups, str):
         groups = groups.split(",")
     ugrps = set(list_groups(name))
     if ugrps == set(groups):
@@ -425,7 +419,7 @@ def chloginclass(name, loginclass, root=None):
     if loginclass == get_loginclass(name):
         return True
 
-    cmd = ["pw", "usermod", "-L", "{0}".format(loginclass), "-n", "{0}".format(name)]
+    cmd = ["pw", "usermod", "-L", "{}".format(loginclass), "-n", "{}".format(name)]
 
     __salt__["cmd.run"](cmd, python_shell=False)
 
@@ -509,7 +503,7 @@ def list_users():
 
         salt '*' user.list_users
     """
-    return sorted([user.pw_name for user in pwd.getpwall()])
+    return sorted(user.pw_name for user in pwd.getpwall())
 
 
 def rename(name, new_name):
@@ -524,10 +518,10 @@ def rename(name, new_name):
     """
     current_info = info(name)
     if not current_info:
-        raise CommandExecutionError("User '{0}' does not exist".format(name))
+        raise CommandExecutionError("User '{}' does not exist".format(name))
     new_info = info(new_name)
     if new_info:
-        raise CommandExecutionError("User '{0}' already exists".format(new_name))
+        raise CommandExecutionError("User '{}' already exists".format(new_name))
     cmd = ["pw", "usermod", "-l", new_name, "-n", name]
     __salt__["cmd.run"](cmd)
     post_info = info(new_name)
