@@ -63,7 +63,10 @@ def __virtual__():
     """
     Only work on systems that have been booted with systemd
     """
-    if __grains__.get("kernel") == "Linux" and salt.utils.systemd.booted(__context__):
+    is_linux = __grains__.get("kernel") == "Linux"
+    is_booted = salt.utils.systemd.booted(__context__)
+    is_offline = salt.utils.systemd.offline(__context__)
+    if is_linux and (is_booted or is_offline):
         return __virtualname__
     return (
         False,
@@ -98,6 +101,11 @@ def _check_available(name):
     """
     Returns boolean telling whether or not the named service is available
     """
+    if offline():
+        raise CommandExecutionError(
+            "Cannot run in offline mode. Failed to get information on unit '%s'" % name
+        )
+
     _status = _systemctl_status(name)
     sd_version = salt.utils.systemd.version(__context__)
     if sd_version is not None and sd_version >= 231:
@@ -297,7 +305,9 @@ def _runlevel():
     contextkey = "systemd._runlevel"
     if contextkey in __context__:
         return __context__[contextkey]
-    out = __salt__["cmd.run"]("runlevel", python_shell=False, ignore_retcode=True)
+    out = __salt__["cmd.run"](
+        salt.utils.path.which("runlevel"), python_shell=False, ignore_retcode=True
+    )
     try:
         ret = out.split()[1]
     except IndexError:
@@ -330,8 +340,8 @@ def _systemctl_cmd(action, name=None, systemd_scope=False, no_block=False, root=
         and salt.utils.systemd.has_scope(__context__)
         and __salt__["config.get"]("systemd.scope", True)
     ):
-        ret.extend(["systemd-run", "--scope"])
-    ret.append("systemctl")
+        ret.extend([salt.utils.path.which("systemd-run"), "--scope"])
+    ret.append(salt.utils.path.which("systemctl"))
     if no_block:
         ret.append("--no-block")
     if root:
@@ -1432,7 +1442,7 @@ def firstboot(
         salt '*' service.firstboot keymap=jp locale=en_US.UTF-8
 
     """
-    cmd = ["systemd-firstboot"]
+    cmd = [salt.utils.path.which("systemd-firstboot")]
     parameters = [
         ("locale", locale),
         ("locale-message", locale_message),
@@ -1452,3 +1462,21 @@ def firstboot(
         raise CommandExecutionError("systemd-firstboot error: {}".format(out["stderr"]))
 
     return True
+
+
+def offline():
+    """
+    .. versionadded:: 3004
+
+    Check if systemd is working in offline mode, where is not possible
+    to talk with PID 1.
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' service.offline
+
+    """
+
+    return salt.utils.systemd.offline(__context__)
