@@ -43,8 +43,8 @@ Creating a client request and its signed certificate
 .. code-block:: bash
 
     # salt-call tls.create_csr my_little CN=DBReplica_No.1 cert_type=client
-    Created Private Key: "/etc/pki/my_little/certs//DBReplica_No.1.key."
-    Created CSR for "DBReplica_No.1": "/etc/pki/my_little/certs/DBReplica_No.1.csr."
+    Created Private Key: "/etc/pki/my_little/certs//DBReplica_No.1.key"
+    Created CSR for "DBReplica_No.1": "/etc/pki/my_little/certs/DBReplica_No.1.csr"
 
     # salt-call tls.create_ca_signed_cert my_little CN=DBReplica_No.1
     Created Certificate for "DBReplica_No.1": "/etc/pki/my_little/certs/DBReplica_No.1.crt"
@@ -56,8 +56,8 @@ Creating both a server and client req + cert for the same CN
 
     # salt-call tls.create_csr my_little CN=MasterDBReplica_No.2  \
         cert_type=client
-    Created Private Key: "/etc/pki/my_little/certs/MasterDBReplica_No.2.key."
-    Created CSR for "DBReplica_No.1": "/etc/pki/my_little/certs/MasterDBReplica_No.2.csr."
+    Created Private Key: "/etc/pki/my_little/certs/MasterDBReplica_No.2.key"
+    Created CSR for "DBReplica_No.1": "/etc/pki/my_little/certs/MasterDBReplica_No.2.csr"
 
     # salt-call tls.create_ca_signed_cert my_little CN=MasterDBReplica_No.2
     Created Certificate for "DBReplica_No.1": "/etc/pki/my_little/certs/DBReplica_No.1.crt"
@@ -70,8 +70,8 @@ Creating both a server and client req + cert for the same CN
 
     # salt-call tls.create_csr my_little CN=MasterDBReplica_No.2 \
         cert_type=server type_ext=True
-    Created Private Key: "/etc/pki/my_little/certs/DBReplica_No.1_client.key."
-    Created CSR for "DBReplica_No.1": "/etc/pki/my_little/certs/DBReplica_No.1_client.csr."
+    Created Private Key: "/etc/pki/my_little/certs/DBReplica_No.1_client.key"
+    Created CSR for "DBReplica_No.1": "/etc/pki/my_little/certs/DBReplica_No.1_client.csr"
 
     # salt-call tls.create_ca_signed_cert my_little CN=MasterDBReplica_No.2
     Certificate "MasterDBReplica_No.2" already exists
@@ -90,8 +90,8 @@ Create a server req + cert with non-CN filename for the cert
 
     # salt-call tls.create_csr my_little CN=www.anothersometh.ing \
         cert_type=server type_ext=True
-    Created Private Key: "/etc/pki/my_little/certs/www.anothersometh.ing_server.key."
-    Created CSR for "DBReplica_No.1": "/etc/pki/my_little/certs/www.anothersometh.ing_server.csr."
+    Created Private Key: "/etc/pki/my_little/certs/www.anothersometh.ing_server.key"
+    Created CSR for "DBReplica_No.1": "/etc/pki/my_little/certs/www.anothersometh.ing_server.csr"
 
     # salt-call tls_create_ca_signed_cert my_little CN=www.anothersometh.ing \
         cert_type=server cert_filename="something_completely_different"
@@ -111,7 +111,7 @@ import salt.utils.data
 import salt.utils.files
 import salt.utils.stringutils
 from salt.exceptions import CommandExecutionError
-from salt.utils.versions import LooseVersion as _LooseVersion
+from salt.utils.versions import Version
 
 # pylint: disable=C0103
 
@@ -122,7 +122,7 @@ try:
     import OpenSSL
 
     HAS_SSL = True
-    OpenSSL_version = _LooseVersion(OpenSSL.__dict__.get("__version__", "0.0"))
+    OpenSSL_version = Version(OpenSSL.__dict__.get("__version__", "0.0"))
 except ImportError:
     pass
 
@@ -138,14 +138,14 @@ def __virtual__():
     Only load this module if the ca config options are set
     """
     global X509_EXT_ENABLED
-    if HAS_SSL and OpenSSL_version >= _LooseVersion("0.10"):
-        if OpenSSL_version < _LooseVersion("0.14"):
+    if HAS_SSL and OpenSSL_version >= Version("0.10"):
+        if OpenSSL_version < Version("0.14"):
             X509_EXT_ENABLED = False
             log.debug(
                 "You should upgrade pyOpenSSL to at least 0.14.1 to "
                 "enable the use of X509 extensions in the tls module"
             )
-        elif OpenSSL_version <= _LooseVersion("0.15"):
+        elif OpenSSL_version <= Version("0.15"):
             log.debug(
                 "You should upgrade pyOpenSSL to at least 0.15.1 to "
                 "enable the full use of X509 extensions in the tls module"
@@ -172,6 +172,14 @@ def _microtime():
     return "{:f}{}".format(val1, val2)
 
 
+def _context_or_config(key):
+    """
+    Return the value corresponding to the key in __context__ or if not present,
+    fallback to config.option.
+    """
+    return __context__.get(key, __salt__["config.option"](key))
+
+
 def cert_base_path(cacert_path=None):
     """
     Return the base path for certs from CLI or from options
@@ -185,16 +193,11 @@ def cert_base_path(cacert_path=None):
 
         salt '*' tls.cert_base_path
     """
-    if not cacert_path:
-        cacert_path = __context__.get(
-            "ca.contextual_cert_base_path",
-            __salt__["config.option"]("ca.contextual_cert_base_path"),
-        )
-    if not cacert_path:
-        cacert_path = __context__.get(
-            "ca.cert_base_path", __salt__["config.option"]("ca.cert_base_path")
-        )
-    return cacert_path
+    return (
+        cacert_path
+        or _context_or_config("ca.contextual_cert_base_path")
+        or _context_or_config("ca.cert_base_path")
+    )
 
 
 def _cert_base_path(cacert_path=None):
@@ -232,7 +235,12 @@ def _new_serial(ca_name):
     """
     hashnum = int(
         binascii.hexlify(
-            b"_".join((salt.utils.stringutils.to_bytes(_microtime()), os.urandom(5),))
+            b"_".join(
+                (
+                    salt.utils.stringutils.to_bytes(_microtime()),
+                    os.urandom(5),
+                )
+            )
         ),
         16,
     )
@@ -249,7 +257,7 @@ def _new_serial(ca_name):
     else:
         mode = "a+"
     with salt.utils.files.fopen(serial_file, mode) as ofile:
-        ofile.write(str(hashnum))  # future lint: disable=blacklisted-function
+        ofile.write(str(hashnum))
 
     return hashnum
 
@@ -322,7 +330,6 @@ def maybe_fix_ssl_version(ca_name, cacert_path=None, ca_filename=None):
 
         .. versionadded:: 2015.5.3
 
-
     CLI Example:
 
     .. code-block:: bash
@@ -337,7 +344,7 @@ def maybe_fix_ssl_version(ca_name, cacert_path=None, ca_filename=None):
     with salt.utils.files.fopen(certp) as fic:
         cert = OpenSSL.crypto.load_certificate(OpenSSL.crypto.FILETYPE_PEM, fic.read())
         if cert.get_version() == 3:
-            log.info("Regenerating wrong x509 version " "for certificate %s", certp)
+            log.info("Regenerating wrong x509 version for certificate %s", certp)
             with salt.utils.files.fopen(ca_keyp) as fic2:
                 try:
                     # try to determine the key bits
@@ -383,7 +390,6 @@ def ca_exists(ca_name, cacert_path=None, ca_filename=None):
 
         .. versionadded:: 2015.5.3
 
-
     CLI Example:
 
     .. code-block:: bash
@@ -452,7 +458,6 @@ def get_ca_signed_cert(
 
         .. versionadded:: 2015.5.3
 
-
     CLI Example:
 
     .. code-block:: bash
@@ -537,7 +542,7 @@ def _read_cert(cert):
 
 def validate(cert, ca_name, crl_file):
     """
-    .. versionadded:: Neon
+    .. versionadded:: 3000
 
     Validate a certificate against a given CA/CRL.
 
@@ -753,8 +758,7 @@ def create_ca(
                 )
             except OpenSSL.crypto.Error as err:
                 log.warning(
-                    "Error loading existing private key"
-                    " %s, generating a new key: %s",
+                    "Error loading existing private key %s, generating a new key: %s",
                     ca_keyp,
                     err,
                 )
@@ -841,10 +845,10 @@ def create_ca(
 
     _write_cert_to_database(ca_name, ca)
 
-    ret = ('Created Private Key: "{}/{}/{}.key." ').format(
+    ret = 'Created Private Key: "{}/{}/{}.key" '.format(
         cert_base_path(), ca_name, ca_filename
     )
-    ret += ('Created CA "{0}": "{1}/{0}/{2}.crt."').format(
+    ret += 'Created CA "{0}": "{1}/{0}/{2}.crt"'.format(
         ca_name, cert_base_path(), ca_filename
     )
 
@@ -1070,9 +1074,9 @@ def create_csr(
         ca_filename = "{}_ca_cert".format(ca_name)
 
     if not ca_exists(ca_name, ca_filename=ca_filename):
-        return (
-            'Certificate for CA named "{}" does not exist, please create ' "it first."
-        ).format(ca_name)
+        return 'Certificate for CA named "{}" does not exist, please create it first.'.format(
+            ca_name
+        )
 
     if not csr_path:
         csr_path = "{}/{}/certs/".format(cert_base_path(), ca_name)
@@ -1167,8 +1171,8 @@ def create_csr(
             )
         )
 
-    ret = 'Created Private Key: "{}{}.key." '.format(csr_path, csr_filename)
-    ret += 'Created CSR for "{}": "{}{}.csr."'.format(CN, csr_path, csr_filename)
+    ret = 'Created Private Key: "{}{}.key" '.format(csr_path, csr_filename)
+    ret += 'Created CSR for "{}": "{}{}.csr"'.format(CN, csr_path, csr_filename)
 
     return ret
 
@@ -1309,10 +1313,10 @@ def create_self_signed_cert(
 
     _write_cert_to_database(tls_dir, cert)
 
-    ret = 'Created Private Key: "{}/{}/certs/{}.key." '.format(
+    ret = 'Created Private Key: "{}/{}/certs/{}.key" '.format(
         cert_base_path(), tls_dir, cert_filename
     )
-    ret += 'Created Certificate: "{}/{}/certs/{}.crt."'.format(
+    ret += 'Created Certificate: "{}/{}/certs/{}.crt"'.format(
         cert_base_path(), tls_dir, cert_filename
     )
 
@@ -1435,7 +1439,7 @@ def create_ca_signed_cert(
     if type_ext:
         if not cert_type:
             log.error(
-                "type_ext = True but cert_type is unset. " "Certificate not written."
+                "type_ext = True but cert_type is unset. Certificate not written."
             )
             return ret
         elif cert_type:
@@ -1630,8 +1634,10 @@ def create_pkcs12(ca_name, CN, passphrase="", cacert_path=None, replace=False):
             pkcs12.export(passphrase=salt.utils.stringutils.to_bytes(passphrase))
         )
 
-    return ('Created PKCS#12 Certificate for "{0}": ' '"{1}/{2}/certs/{0}.p12"').format(
-        CN, cert_base_path(), ca_name,
+    return 'Created PKCS#12 Certificate for "{0}": "{1}/{2}/certs/{0}.p12"'.format(
+        CN,
+        cert_base_path(),
+        ca_name,
     )
 
 
@@ -1714,7 +1720,7 @@ def cert_info(cert, digest="sha256"):
             entry, name = name.split(":", 1)
             if entry not in valid_entries:
                 log.error(
-                    "Cert %s has an entry (%s) which does not start " "with %s",
+                    "Cert %s has an entry (%s) which does not start with %s",
                     ret["subject"],
                     name,
                     "/".join(valid_entries),
@@ -1800,7 +1806,9 @@ def create_empty_crl(
 
     crl = OpenSSL.crypto.CRL()
     crl_text = crl.export(
-        ca_cert, ca_key, digest=salt.utils.stringutils.to_bytes(digest),
+        ca_cert,
+        ca_key,
+        digest=salt.utils.stringutils.to_bytes(digest),
     )
 
     with salt.utils.files.fopen(crl_file, "w") as f:
@@ -1916,14 +1924,15 @@ def revoke_cert(
                 revoke_date = line.split("\t")[2]
                 try:
                     datetime.strptime(revoke_date, two_digit_year_fmt)
-                    return (
-                        '"{}/{}.crt" was already revoked, ' "serial number: {}"
-                    ).format(cert_path, cert_filename, serial_number)
+                    return '"{}/{}.crt" was already revoked, serial number: {}'.format(
+                        cert_path, cert_filename, serial_number
+                    )
                 except ValueError:
                     ret["retcode"] = 1
-                    ret["comment"] = (
-                        "Revocation date '{}' does not match"
-                        "format '{}'".format(revoke_date, two_digit_year_fmt)
+                    ret[
+                        "comment"
+                    ] = "Revocation date '{}' does not matchformat '{}'".format(
+                        revoke_date, two_digit_year_fmt
                     )
                     return ret
             elif index_serial_subject in line:
@@ -1964,7 +1973,7 @@ def revoke_cert(
     with salt.utils.files.fopen(crl_file, "w") as fp_:
         fp_.write(salt.utils.stringutils.to_str(crl_text))
 
-    return ('Revoked Certificate: "{}/{}.crt", ' "serial number: {}").format(
+    return 'Revoked Certificate: "{}/{}.crt", serial number: {}'.format(
         cert_path, cert_filename, serial_number
     )
 
