@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
 """
-Module for managing Windows Users
+Module for managing Windows Users.
 
 .. important::
     If you feel that Salt should be using this module to manage users on a
@@ -22,33 +21,22 @@ Module for managing Windows Users
 .. note::
     This currently only works with local user accounts, not domain accounts
 """
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
+import shlex
 import time
 from datetime import datetime
 
-# Import Salt libs
 import salt.utils.args
 import salt.utils.dateutils
 import salt.utils.platform
 import salt.utils.winapi
 from salt.exceptions import CommandExecutionError
-from salt.ext import six
-from salt.ext.six import string_types
-
-try:
-    from shlex import quote as _cmd_quote  # pylint: disable=E0611
-except Exception:  # pylint: disable=broad-except
-    from pipes import quote as _cmd_quote
-
 
 log = logging.getLogger(__name__)
 
 try:
     import pywintypes
-    import wmi
     import win32api
     import win32con
     import win32net
@@ -56,6 +44,7 @@ try:
     import win32profile
     import win32security
     import win32ts
+    import wmi
 
     HAS_WIN32NET_MODS = True
 except ImportError:
@@ -78,27 +67,6 @@ def __virtual__():
     return __virtualname__
 
 
-def _to_unicode(instr):
-    """
-    Internal function for converting to Unicode Strings
-
-    The NetUser* series of API calls in this module requires input parameters to
-    be Unicode Strings. This function ensures the parameter is a Unicode String.
-    This only seems to be an issue in Python 2. All calls to this function
-    should be gated behind a ``if six.PY2`` check.
-
-    Args:
-        instr (str): String to convert
-
-    Returns:
-        str: Unicode type string
-    """
-    if instr is None or isinstance(instr, six.text_type):
-        return instr
-    else:
-        return six.text_type(instr, "utf-8")
-
-
 def add(
     name,
     password=None,
@@ -146,16 +114,6 @@ def add(
 
         salt '*' user.add name password
     """
-    if six.PY2:
-        name = _to_unicode(name)
-        password = _to_unicode(password)
-        fullname = _to_unicode(fullname)
-        description = _to_unicode(description)
-        home = _to_unicode(home)
-        homedrive = _to_unicode(homedrive)
-        profile = _to_unicode(profile)
-        logonscript = _to_unicode(logonscript)
-
     user_info = {}
     if name:
         user_info["name"] = name
@@ -175,7 +133,7 @@ def add(
         log.error("nbr: %s", exc.winerror)
         log.error("ctx: %s", exc.funcname)
         log.error("msg: %s", exc.strerror)
-        return False
+        return exc.strerror
 
     update(name=name, homedrive=homedrive, profile=profile, fullname=fullname)
 
@@ -255,19 +213,9 @@ def update(
     .. code-block:: bash
 
         salt '*' user.update bob password=secret profile=C:\\Users\\Bob
-                 home=\\server\homeshare\bob homedrive=U:
+                 home=\\server\\homeshare\\bob homedrive=U:
     """
     # pylint: enable=anomalous-backslash-in-string
-    if six.PY2:
-        name = _to_unicode(name)
-        password = _to_unicode(password)
-        fullname = _to_unicode(fullname)
-        description = _to_unicode(description)
-        home = _to_unicode(home)
-        homedrive = _to_unicode(homedrive)
-        logonscript = _to_unicode(logonscript)
-        profile = _to_unicode(profile)
-
     # Make sure the user exists
     # Return an object containing current settings for the user
     try:
@@ -277,7 +225,7 @@ def update(
         log.error("nbr: %s", exc.winerror)
         log.error("ctx: %s", exc.funcname)
         log.error("msg: %s", exc.strerror)
-        return False
+        return exc.strerror
 
     # Check parameters to update
     # Update the user object with new settings
@@ -302,7 +250,7 @@ def update(
             try:
                 dt_obj = salt.utils.dateutils.date_cast(expiration_date)
             except (ValueError, RuntimeError):
-                return "Invalid Date/Time Format: {0}".format(expiration_date)
+                return "Invalid Date/Time Format: {}".format(expiration_date)
             user_info["acct_expires"] = time.mktime(dt_obj.timetuple())
     if expired is not None:
         if expired:
@@ -336,7 +284,7 @@ def update(
         log.error("nbr: %s", exc.winerror)
         log.error("ctx: %s", exc.funcname)
         log.error("msg: %s", exc.strerror)
-        return False
+        return exc.strerror
 
     return True
 
@@ -365,9 +313,6 @@ def delete(name, purge=False, force=False):
 
         salt '*' user.delete name
     """
-    if six.PY2:
-        name = _to_unicode(name)
-
     # Check if the user exists
     try:
         user_info = win32net.NetUserGetInfo(None, name, 4)
@@ -376,7 +321,7 @@ def delete(name, purge=False, force=False):
         log.error("nbr: %s", exc.winerror)
         log.error("ctx: %s", exc.funcname)
         log.error("msg: %s", exc.strerror)
-        return False
+        return exc.strerror
 
     # Check if the user is logged in
     # Return a list of logged in users
@@ -414,7 +359,7 @@ def delete(name, purge=False, force=False):
                 log.error("nbr: %s", exc.winerror)
                 log.error("ctx: %s", exc.funcname)
                 log.error("msg: %s", exc.strerror)
-                return False
+                return exc.strerror
         else:
             log.error("User %s is currently logged in.", name)
             return False
@@ -433,7 +378,7 @@ def delete(name, purge=False, force=False):
                 log.error("nbr: %s", exc.winerror)
                 log.error("ctx: %s", exc.funcname)
                 log.error("msg: %s", exc.strerror)
-                return False
+                return exc.strerror
 
     # And finally remove the user account
     try:
@@ -443,7 +388,7 @@ def delete(name, purge=False, force=False):
         log.error("nbr: %s", exc.winerror)
         log.error("ctx: %s", exc.funcname)
         log.error("msg: %s", exc.strerror)
-        return False
+        return exc.strerror
 
     return True
 
@@ -464,9 +409,6 @@ def getUserSid(username):
 
         salt '*' user.getUserSid jsnuffy
     """
-    if six.PY2:
-        username = _to_unicode(username)
-
     domain = win32api.GetComputerName()
     if username.find("\\") != -1:
         domain = username.split("\\")[0]
@@ -516,12 +458,8 @@ def addgroup(name, group):
 
         salt '*' user.addgroup jsnuffy 'Power Users'
     """
-    if six.PY2:
-        name = _to_unicode(name)
-        group = _to_unicode(group)
-
-    name = _cmd_quote(name)
-    group = _cmd_quote(group).lstrip("'").rstrip("'")
+    name = shlex.quote(name)
+    group = shlex.quote(group).lstrip("'").rstrip("'")
 
     user = info(name)
     if not user:
@@ -529,7 +467,7 @@ def addgroup(name, group):
     if group in user["groups"]:
         return True
 
-    cmd = 'net localgroup "{0}" {1} /add'.format(group, name)
+    cmd = 'net localgroup "{}" {} /add'.format(group, name)
     ret = __salt__["cmd.run_all"](cmd, python_shell=True)
 
     return ret["retcode"] == 0
@@ -553,12 +491,8 @@ def removegroup(name, group):
 
         salt '*' user.removegroup jsnuffy 'Power Users'
     """
-    if six.PY2:
-        name = _to_unicode(name)
-        group = _to_unicode(group)
-
-    name = _cmd_quote(name)
-    group = _cmd_quote(group).lstrip("'").rstrip("'")
+    name = shlex.quote(name)
+    group = shlex.quote(group).lstrip("'").rstrip("'")
 
     user = info(name)
 
@@ -568,7 +502,7 @@ def removegroup(name, group):
     if group not in user["groups"]:
         return True
 
-    cmd = 'net localgroup "{0}" {1} /delete'.format(group, name)
+    cmd = 'net localgroup "{}" {} /delete'.format(group, name)
     ret = __salt__["cmd.run_all"](cmd, python_shell=True)
 
     return ret["retcode"] == 0
@@ -593,10 +527,6 @@ def chhome(name, home, **kwargs):
 
         salt '*' user.chhome foo \\\\fileserver\\home\\foo True
     """
-    if six.PY2:
-        name = _to_unicode(name)
-        home = _to_unicode(home)
-
     kwargs = salt.utils.args.clean_kwargs(**kwargs)
     persist = kwargs.pop("persist", False)
     if kwargs:
@@ -689,34 +619,28 @@ def chgroups(name, groups, append=True):
 
         salt '*' user.chgroups jsnuffy Administrators,Users True
     """
-    if six.PY2:
-        name = _to_unicode(name)
-
-    if isinstance(groups, string_types):
+    if isinstance(groups, str):
         groups = groups.split(",")
 
     groups = [x.strip(" *") for x in groups]
-    if six.PY2:
-        groups = [_to_unicode(x) for x in groups]
-
     ugrps = set(list_groups(name))
     if ugrps == set(groups):
         return True
 
-    name = _cmd_quote(name)
+    name = shlex.quote(name)
 
     if not append:
         for group in ugrps:
-            group = _cmd_quote(group).lstrip("'").rstrip("'")
+            group = shlex.quote(group).lstrip("'").rstrip("'")
             if group not in groups:
-                cmd = 'net localgroup "{0}" {1} /delete'.format(group, name)
+                cmd = 'net localgroup "{}" {} /delete'.format(group, name)
                 __salt__["cmd.run_all"](cmd, python_shell=True)
 
     for group in groups:
         if group in ugrps:
             continue
-        group = _cmd_quote(group).lstrip("'").rstrip("'")
-        cmd = 'net localgroup "{0}" {1} /add'.format(group, name)
+        group = shlex.quote(group).lstrip("'").rstrip("'")
+        cmd = 'net localgroup "{}" {} /add'.format(group, name)
         out = __salt__["cmd.run_all"](cmd, python_shell=True)
         if out["retcode"] != 0:
             log.error(out["stdout"])
@@ -763,9 +687,6 @@ def info(name):
 
         salt '*' user.info jsnuffy
     """
-    if six.PY2:
-        name = _to_unicode(name)
-
     ret = {}
     items = {}
     try:
@@ -853,7 +774,7 @@ def _get_userprofile_from_registry(user, sid):
     """
     profile_dir = __utils__["reg.read_value"](
         "HKEY_LOCAL_MACHINE",
-        "SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\ProfileList\\{0}".format(sid),
+        "SOFTWARE\\Microsoft\\Windows NT\\CurrentVersion\\ProfileList\\{}".format(sid),
         "ProfileImagePath",
     )["vdata"]
     log.debug('user %s with sid=%s profile is located at "%s"', user, sid, profile_dir)
@@ -876,9 +797,6 @@ def list_groups(name):
 
         salt '*' user.list_groups foo
     """
-    if six.PY2:
-        name = _to_unicode(name)
-
     ugrp = set()
     try:
         user = info(name)["groups"]
@@ -980,19 +898,15 @@ def rename(name, new_name):
 
         salt '*' user.rename jsnuffy jshmoe
     """
-    if six.PY2:
-        name = _to_unicode(name)
-        new_name = _to_unicode(new_name)
-
     # Load information for the current name
     current_info = info(name)
     if not current_info:
-        raise CommandExecutionError("User '{0}' does not exist".format(name))
+        raise CommandExecutionError("User '{}' does not exist".format(name))
 
     # Look for an existing user with the new name
     new_info = info(new_name)
     if new_info:
-        raise CommandExecutionError("User '{0}' already exists".format(new_name))
+        raise CommandExecutionError("User '{}' already exists".format(new_name))
 
     # Rename the user account
     # Connect to WMI
@@ -1003,7 +917,7 @@ def rename(name, new_name):
         try:
             user = c.Win32_UserAccount(Name=name)[0]
         except IndexError:
-            raise CommandExecutionError("User '{0}' does not exist".format(name))
+            raise CommandExecutionError("User '{}' does not exist".format(name))
 
         # Rename the user
         result = user.Rename(new_name)[0]
@@ -1018,14 +932,20 @@ def rename(name, new_name):
                 3: "Invalid parameter",
                 4: "User not found",
                 5: "Domain not found",
-                6: "Operation is allowed only on the primary domain controller of the domain",
+                6: (
+                    "Operation is allowed only on the primary domain controller of the"
+                    " domain"
+                ),
                 7: "Operation is not allowed on the last administrative account",
-                8: "Operation is not allowed on specified special groups: user, admin, local, or guest",
+                8: (
+                    "Operation is not allowed on specified special groups: user, admin,"
+                    " local, or guest"
+                ),
                 9: "Other API error",
                 10: "Internal error",
             }
             raise CommandExecutionError(
-                "There was an error renaming '{0}' to '{1}'. Error: {2}".format(
+                "There was an error renaming '{}' to '{}'. Error: {}".format(
                     name, new_name, error_dict[result]
                 )
             )
