@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Return data to a postgresql server
 
@@ -126,24 +125,16 @@ To override individual configuration items, append --return_kwargs '{"key:": "va
     salt '*' test.ping --return postgres --return_kwargs '{"db": "another-salt"}'
 
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
-
-# Import python libs
 import sys
 from contextlib import contextmanager
 
 import salt.exceptions
 import salt.returners
-
-# Import Salt libs
-import salt.utils.jid
+import salt.utils.data
 import salt.utils.json
 
-# Import third party libs
-from salt.ext import six
-
 try:
     import psycopg2
 
@@ -183,7 +174,7 @@ def _get_options(ret=None):
     }
 
     _options = salt.returners.get_returner_options(
-        "returner.{0}".format(__virtualname__),
+        "returner.{}".format(__virtualname__),
         ret,
         attrs,
         __salt__=__salt__,
@@ -222,9 +213,9 @@ def _get_serv(ret=None, commit=False):
         yield cursor
     except psycopg2.DatabaseError as err:
         error = err.args
-        sys.stderr.write(six.text_type(error))
+        sys.stderr.write(str(error))
         cursor.execute("ROLLBACK")
-        six.reraise(*sys.exc_info())
+        raise
     else:
         if commit:
             cursor.execute("COMMIT")
@@ -243,20 +234,22 @@ def returner(ret):
             sql = """INSERT INTO salt_returns
                     (fun, jid, return, id, success, full_ret)
                     VALUES (%s, %s, %s, %s, %s, %s)"""
+            cleaned_return = salt.utils.data.decode(ret)
             cur.execute(
                 sql,
                 (
                     ret["fun"],
                     ret["jid"],
-                    salt.utils.json.dumps(ret["return"]),
+                    salt.utils.json.dumps(cleaned_return["return"]),
                     ret["id"],
                     ret.get("success", False),
-                    salt.utils.json.dumps(ret),
+                    salt.utils.json.dumps(cleaned_return),
                 ),
             )
     except salt.exceptions.SaltMasterError:
         log.critical(
-            "Could not store return with postgres returner. PostgreSQL server unavailable."
+            "Could not store return with postgres returner. PostgreSQL server"
+            " unavailable."
         )
 
 
@@ -286,8 +279,9 @@ def save_load(jid, load, minions=None):  # pylint: disable=unused-argument
                (jid, load)
                 VALUES (%s, %s)"""
 
+        json_data = salt.utils.json.dumps(salt.utils.data.decode(load))
         try:
-            cur.execute(sql, (jid, salt.utils.json.dumps(load)))
+            cur.execute(sql, (jid, json_data))
         except psycopg2.IntegrityError:
             # https://github.com/saltstack/salt/issues/22171
             # Without this try/except we get tons of duplicate entry errors
