@@ -139,7 +139,7 @@ def lookup_jid(
     try:
         data = list_job(jid, ext_source=ext_source, display_progress=display_progress)
     except TypeError:
-        return "Requested returner could not be loaded. " "No JIDs could be retrieved."
+        return "Requested returner could not be loaded. No JIDs could be retrieved."
 
     targeted_minions = data.get("Minions", [])
     returns = data.get("Result", {})
@@ -355,8 +355,7 @@ def list_jobs(
                     _match = True
             else:
                 log.error(
-                    "'dateutil' library not available, skipping start_time "
-                    "comparison."
+                    "'dateutil' library not available, skipping start_time comparison."
                 )
 
         if end_time and _match:
@@ -368,7 +367,7 @@ def list_jobs(
                     _match = True
             else:
                 log.error(
-                    "'dateutil' library not available, skipping end_time " "comparison."
+                    "'dateutil' library not available, skipping end_time comparison."
                 )
 
         if _match:
@@ -584,21 +583,19 @@ def _walk_through(job_dir, display_progress=False):
     """
     Walk through the job dir and return jobs
     """
-    serial = salt.payload.Serial(__opts__)
-
     for top in os.listdir(job_dir):
         t_path = os.path.join(job_dir, top)
 
         for final in os.listdir(t_path):
             load_path = os.path.join(t_path, final, ".load.p")
             with salt.utils.files.fopen(load_path, "rb") as rfh:
-                job = serial.load(rfh)
+                job = salt.payload.load(rfh)
 
             if not os.path.isfile(load_path):
                 continue
 
             with salt.utils.files.fopen(load_path, "rb") as rfh:
-                job = serial.load(rfh)
+                job = salt.payload.load(rfh)
             jid = job["jid"]
             if display_progress:
                 __jid_event__.fire_event(
