@@ -1,21 +1,19 @@
-# -*- coding: utf-8 -*-
 """
 This module contains the function calls to execute command line scripts
 """
-
-from __future__ import absolute_import, print_function, unicode_literals
-
+import contextlib
 import functools
 import logging
 import os
 import signal
+import subprocess
 import sys
 import threading
 import time
 import traceback
 from random import randint
 
-import salt.defaults.exitcodes  # pylint: disable=unused-import
+import salt.defaults.exitcodes
 from salt.exceptions import SaltClientError, SaltReqTimeoutError, SaltSystemExit
 
 log = logging.getLogger(__name__)
@@ -24,31 +22,7 @@ if sys.version_info < (3,):
     raise SystemExit(salt.defaults.exitcodes.EX_GENERIC)
 
 
-def _handle_interrupt(exc, original_exc, hardfail=False, trace=""):
-    """
-    if hardfailing:
-        If we got the original stacktrace, log it
-        If all cases, raise the original exception
-        but this is logically part the initial
-        stack.
-    else just let salt exit gracefully
-
-    """
-    if hardfail:
-        if trace:
-            log.error(trace)
-        raise original_exc
-    else:
-        raise exc
-
-
 def _handle_signals(client, signum, sigframe):
-    try:
-        # This raises AttributeError on Python 3.4 and 3.5 if there is no current exception.
-        # Ref: https://bugs.python.org/issue23003
-        trace = traceback.format_exc()
-    except AttributeError:
-        trace = ""
     try:
         hardcrash = client.options.hard_crash
     except (AttributeError, KeyError):
@@ -71,23 +45,31 @@ def _handle_signals(client, signum, sigframe):
     else:
         exit_msg = None
 
-    _handle_interrupt(
-        SystemExit(exit_msg),
-        Exception("\nExiting with hard crash on Ctrl-c"),
-        hardcrash,
-        trace=trace,
-    )
+    if exit_msg is None and hardcrash:
+        exit_msg = "\nExiting with hard crash on Ctrl-c"
+    if exit_msg:
+        print(exit_msg, file=sys.stderr, flush=True)
+    if hardcrash:
+        try:
+            # This raises AttributeError on Python 3.4 and 3.5 if there is no current exception.
+            # Ref: https://bugs.python.org/issue23003
+            trace = traceback.format_exc()
+            log.error(trace)
+        except AttributeError:
+            pass
+        sys.exit(salt.defaults.exitcodes.EX_GENERIC)
+    sys.exit(salt.defaults.exitcodes.EX_OK)
 
 
 def _install_signal_handlers(client):
     # Install the SIGINT/SIGTERM handlers if not done so far
-    if signal.getsignal(signal.SIGINT) is signal.SIG_DFL:
+    if signal.getsignal(signal.SIGINT) in (signal.SIG_DFL, signal.default_int_handler):
         # No custom signal handling was added, install our own
         signal.signal(signal.SIGINT, functools.partial(_handle_signals, client))
 
     if signal.getsignal(signal.SIGTERM) is signal.SIG_DFL:
         # No custom signal handling was added, install our own
-        signal.signal(signal.SIGINT, functools.partial(_handle_signals, client))
+        signal.signal(signal.SIGTERM, functools.partial(_handle_signals, client))
 
 
 def salt_master():
@@ -110,14 +92,19 @@ def minion_process():
     """
     Start a minion process
     """
-    import salt.utils.platform
-    import salt.utils.process
+    # Because the minion is going to start on a separate process,
+    # salt._logging.in_mainprocess() will return False.
+    # We'll just force it to return True for this particular case so
+    # that proper logging can be set up.
+    import salt._logging
+
+    salt._logging.in_mainprocess.__pid__ = os.getpid()
+    # Now the remaining required imports
     import salt.cli.daemons
+    import salt.utils.platform
 
     # salt_minion spawns this function in a new process
 
-    salt.utils.process.appendproctitle("KeepAlive")
-
     def handle_hup(manager, sig, frame):
         manager.minion.reload()
 
@@ -182,9 +169,10 @@ def salt_minion():
 
     salt.utils.process.notify_systemd()
 
-    import salt.cli.daemons
     import multiprocessing
 
+    import salt.cli.daemons
+
     # Fix for setuptools generated scripts, so that it will
     # work with multiprocessing fork emulation.
     # (see multiprocessing.forking.get_preparation_data())
@@ -220,7 +208,9 @@ def salt_minion():
     prev_sigterm_handler = signal.getsignal(signal.SIGTERM)
     while True:
         try:
-            process = multiprocessing.Process(target=minion_process)
+            process = multiprocessing.Process(
+                target=minion_process, name="MinionKeepAlive"
+            )
             process.start()
             signal.signal(
                 signal.SIGTERM,
@@ -303,7 +293,12 @@ def proxy_minion_process(queue):
         proxyminion = salt.cli.daemons.ProxyMinion()
         proxyminion.start()
         # pylint: disable=broad-except
-    except (Exception, SaltClientError, SaltReqTimeoutError, SaltSystemExit,) as exc:
+    except (
+        Exception,
+        SaltClientError,
+        SaltReqTimeoutError,
+        SaltSystemExit,
+    ) as exc:
         # pylint: enable=broad-except
         log.error("Proxy Minion failed to start: ", exc_info=True)
         restart = True
@@ -334,9 +329,10 @@ def salt_proxy():
     """
     Start a proxy minion.
     """
+    import multiprocessing
+
     import salt.cli.daemons
     import salt.utils.platform
-    import multiprocessing
 
     if "" in sys.path:
         sys.path.remove("")
@@ -361,7 +357,9 @@ def salt_proxy():
             proxyminion = salt.cli.daemons.ProxyMinion()
             proxyminion.start()
             return
-        process = multiprocessing.Process(target=proxy_minion_process, args=(queue,))
+        process = multiprocessing.Process(
+            target=proxy_minion_process, args=(queue,), name="ProxyMinion"
+        )
         process.start()
         try:
             process.join()
@@ -416,7 +414,7 @@ def salt_key():
         _install_signal_handlers(client)
         client.run()
     except Exception as err:  # pylint: disable=broad-except
-        sys.stderr.write("Error: {0}\n".format(err))
+        sys.stderr.write("Error: {}\n".format(err))
 
 
 def salt_cp():
@@ -471,12 +469,14 @@ def salt_ssh():
         _install_signal_handlers(client)
         client.run()
     except SaltClientError as err:
-        trace = traceback.format_exc()
+        print(str(err), file=sys.stderr, flush=True)
         try:
-            hardcrash = client.options.hard_crash
+            if client.options.hard_crash:
+                trace = traceback.format_exc()
+                log.error(trace)
         except (AttributeError, KeyError):
-            hardcrash = False
-        _handle_interrupt(SystemExit(err), err, hardcrash, trace=trace)
+            pass
+        sys.exit(salt.defaults.exitcodes.EX_GENERIC)
 
 
 def salt_cloud():
@@ -572,7 +572,7 @@ def salt_unity():
     if len(sys.argv) < 2:
         msg = "Must pass in a salt command, available commands are:"
         for cmd in avail:
-            msg += "\n{0}".format(cmd)
+            msg += "\n{}".format(cmd)
         print(msg)
         sys.exit(1)
     cmd = sys.argv[1]
@@ -581,7 +581,60 @@ def salt_unity():
         sys.argv[0] = "salt"
         s_fun = salt_main
     else:
-        sys.argv[0] = "salt-{0}".format(cmd)
+        sys.argv[0] = "salt-{}".format(cmd)
         sys.argv.pop(1)
-        s_fun = getattr(sys.modules[__name__], "salt_{0}".format(cmd))
+        s_fun = getattr(sys.modules[__name__], "salt_{}".format(cmd))
     s_fun()
+
+
+def _pip_args(args, target):
+    new_args = args[:]
+    target_in_args = False
+    for arg in args:
+        if "--target" in arg:
+            target_in_args = True
+    if "install" in args and not target_in_args:
+        new_args.append(f"--target={target}")
+    return new_args
+
+
+def _pip_environment(env, extras):
+    new_env = env.copy()
+    if "PYTHONPATH" in env:
+        new_env["PYTHONPATH"] = f"{extras}{os.pathsep}{env['PYTHONPATH']}"
+    else:
+        new_env["PYTHONPATH"] = extras
+    return new_env
+
+
+def _get_onedir_env_path():
+    # This function only exists to simplify testing.
+    with contextlib.suppress(AttributeError):
+        return sys.RELENV
+    return None
+
+
+def salt_pip():
+    """
+    Proxy to current python's pip
+    """
+    relenv_path = _get_onedir_env_path()
+    if relenv_path is None:
+        print(
+            "'salt-pip' is only meant to be used from a Salt onedir. You probably "
+            "want to use the system 'pip` binary.",
+            file=sys.stderr,
+            flush=True,
+        )
+        sys.exit(salt.defaults.exitcodes.EX_GENERIC)
+    else:
+        extras = str(relenv_path / "extras-{}.{}".format(*sys.version_info))
+    env = _pip_environment(os.environ.copy(), extras)
+    args = _pip_args(sys.argv[1:], extras)
+    command = [
+        sys.executable,
+        "-m",
+        "pip",
+    ] + _pip_args(sys.argv[1:], extras)
+    ret = subprocess.run(command, shell=False, check=False, env=env)
+    sys.exit(ret.returncode)
