@@ -4,16 +4,17 @@ Execution of Salt modules from within states
 
 .. note::
 
-    There are two styles of calling ``module.run``. **The legacy style will no
-    longer be available starting in the 3005 release.** To opt-in early to the
-    new style you must add the following to your ``/etc/salt/minion`` config
-    file:
+    As of the 3005 release, you no longer need to opt-in to the new style of
+    calling ``module.run``. The following config can be removed from ``/etc/salt/minion``:
 
     .. code-block:: yaml
 
         use_superseded:
           - module.run
 
+    Both 'new' and 'legacy' styles of calling ``module.run`` are supported.
+
+
 With `module.run` these states allow individual execution module calls to be
 made via states. Here's a contrived example, to show you how it's done:
 
@@ -297,16 +298,17 @@ Windows system:
               start_time: '11:59PM'
         }
 
-.. _file_roots: https://docs.saltstack.com/en/latest/ref/configuration/master.html#file-roots
+.. _file_roots: https://docs.saltproject.io/en/latest/ref/configuration/master.html#file-roots
 """
+import logging
 
 import salt.loader
 import salt.utils.args
 import salt.utils.functools
 import salt.utils.jid
 from salt.exceptions import SaltInvocationError
-from salt.ext.six.moves import range
-from salt.utils.decorators import with_deprecated
+
+log = logging.getLogger(__name__)
 
 
 def wait(name, **kwargs):
@@ -338,7 +340,6 @@ def wait(name, **kwargs):
 watch = salt.utils.functools.alias_function(wait, "watch")
 
 
-@with_deprecated(globals(), "Phosphorus", policy=with_deprecated.OPT_IN)
 def run(**kwargs):
     """
     Run a single module function or a range of module functions in a batch.
@@ -371,6 +372,31 @@ def run(**kwargs):
 
     :return:
     """
+    # Detect if this call is using legacy or new style syntax.
+    legacy_run = False
+
+    keys = list(kwargs)
+    ignored_kwargs = ["name", "__reqs__", "sfun"]
+    for item in ignored_kwargs:
+        if item in keys:
+            keys.remove(item)
+
+    # The rest of the keys should be function names for new-style syntax
+    for name in keys:
+        if name.find(".") == -1:
+            legacy_run = True
+    if not keys and kwargs:
+        legacy_run = True
+
+    if legacy_run:
+        log.debug("Detected legacy module.run syntax: %s", __low__["__id__"])
+        return _legacy_run(**kwargs)
+    else:
+        log.debug("Using new style module.run syntax: %s", __low__["__id__"])
+        return _run(**kwargs)
+
+
+def _run(**kwargs):
 
     if "name" in kwargs:
         kwargs.pop("name")
@@ -400,15 +426,13 @@ def run(**kwargs):
         ret["comment"] = " ".join(
             [
                 missing
-                and "Unavailable function{plr}: "
-                "{func}.".format(
+                and "Unavailable function{plr}: {func}.".format(
                     plr=(len(missing) > 1 or ""), func=(", ".join(missing) or "")
                 )
                 or "",
                 tests
-                and "Function{plr} {func} to be "
-                "executed.".format(
-                    plr=(len(tests) > 1 or ""), func=(", ".join(tests)) or ""
+                and "Function{plr} {func} to be executed.".format(
+                    plr=(len(tests) > 1 or ""), func=", ".join(tests) or ""
                 )
                 or "",
             ]
@@ -485,7 +509,7 @@ def _call_function(name, returner=None, func_args=None, func_kwargs=None):
     return mret
 
 
-def _run(name, **kwargs):
+def _legacy_run(name, **kwargs):
     """
     .. deprecated:: 2017.7.0
        Function name stays the same, behaviour will change.
