@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manage software from FreeBSD ports
 
@@ -14,9 +13,7 @@ Manage software from FreeBSD ports
 
         salt -t 1200 '*' state.highstate
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import python libs
 import copy
 import logging
 
@@ -24,10 +21,8 @@ import logging
 import os  # pylint: disable=W0611
 import sys
 
-# Import salt libs
 import salt.utils.data
 from salt.exceptions import CommandExecutionError, SaltInvocationError
-from salt.ext import six
 from salt.modules.freebsdports import _normalize, _options_file_exists
 
 log = logging.getLogger(__name__)
@@ -43,12 +38,10 @@ def _repack_options(options):
     """
     Repack the options data
     """
-    return dict(
-        [
-            (six.text_type(x), _normalize(y))
-            for x, y in six.iteritems(salt.utils.data.repack_dictlist(options))
-        ]
-    )
+    return {
+        str(x): _normalize(y)
+        for x, y in salt.utils.data.repack_dictlist(options).items()
+    }
 
 
 def _get_option_list(options):
@@ -56,7 +49,7 @@ def _get_option_list(options):
     Returns the key/value pairs in the passed dict in a commaspace-delimited
     list in the format "key=value".
     """
-    return ", ".join(["{0}={1}".format(x, y) for x, y in six.iteritems(options)])
+    return ", ".join(["{}={}".format(x, y) for x, y in options.items()])
 
 
 def _build_option_string(options):
@@ -64,7 +57,7 @@ def _build_option_string(options):
     Common function to get a string to append to the end of the state comment
     """
     if options:
-        return "with the following build options: {0}".format(_get_option_list(options))
+        return "with the following build options: {}".format(_get_option_list(options))
     else:
         return "with the default build options"
 
@@ -96,7 +89,7 @@ def installed(name, options=None):
         "name": name,
         "changes": {},
         "result": True,
-        "comment": "{0} is already installed".format(name),
+        "comment": "{} is already installed".format(name),
     }
     try:
         current_options = __salt__["ports.showconfig"](
@@ -113,9 +106,9 @@ def installed(name, options=None):
     except (SaltInvocationError, CommandExecutionError) as exc:
         ret["result"] = False
         ret["comment"] = (
-            "Unable to get configuration for {0}. Port name may "
+            "Unable to get configuration for {}. Port name may "
             "be invalid, or ports tree may need to be updated. "
-            "Error message: {1}".format(name, exc)
+            "Error message: {}".format(name, exc)
         )
         return ret
 
@@ -123,7 +116,7 @@ def installed(name, options=None):
     desired_options = copy.deepcopy(default_options)
     desired_options.update(options)
     ports_pre = [
-        x["origin"] for x in six.itervalues(__salt__["pkg.list_pkgs"](with_origin=True))
+        x["origin"] for x in __salt__["pkg.list_pkgs"](with_origin=True).values()
     ]
 
     if current_options == desired_options and name in ports_pre:
@@ -135,47 +128,49 @@ def installed(name, options=None):
     if not default_options:
         if options:
             ret["result"] = False
-            ret["comment"] = (
-                "{0} does not have any build options, yet "
-                "options were specified".format(name)
+            ret[
+                "comment"
+            ] = "{} does not have any build options, yet options were specified".format(
+                name
             )
             return ret
         else:
             if __opts__["test"]:
                 ret["result"] = None
-                ret["comment"] = "{0} will be installed".format(name)
+                ret["comment"] = "{} will be installed".format(name)
                 return ret
     else:
         bad_opts = [x for x in options if x not in default_options]
         if bad_opts:
             ret["result"] = False
-            ret["comment"] = (
-                "The following options are not available for "
-                "{0}: {1}".format(name, ", ".join(bad_opts))
+            ret[
+                "comment"
+            ] = "The following options are not available for {}: {}".format(
+                name, ", ".join(bad_opts)
             )
             return ret
 
         if __opts__["test"]:
             ret["result"] = None
-            ret["comment"] = "{0} will be installed ".format(name)
+            ret["comment"] = "{} will be installed ".format(name)
             ret["comment"] += _build_option_string(options)
             return ret
 
         if options:
             if not __salt__["ports.config"](name, reset=True, **options):
                 ret["result"] = False
-                ret["comment"] = "Unable to set options for {0}".format(name)
+                ret["comment"] = "Unable to set options for {}".format(name)
                 return ret
         else:
             __salt__["ports.rmconfig"](name)
             if _options_file_exists(name):
                 ret["result"] = False
-                ret["comment"] = "Unable to clear options for {0}".format(name)
+                ret["comment"] = "Unable to clear options for {}".format(name)
                 return ret
 
     ret["changes"] = __salt__["ports.install"](name)
     ports_post = [
-        x["origin"] for x in six.itervalues(__salt__["pkg.list_pkgs"](with_origin=True))
+        x["origin"] for x in __salt__["pkg.list_pkgs"](with_origin=True).values()
     ]
     err = sys.modules[__salt__["test.ping"].__module__].__context__.pop(
         "ports.install_error", None
@@ -183,11 +178,11 @@ def installed(name, options=None):
     if err or name not in ports_post:
         ret["result"] = False
     if ret["result"]:
-        ret["comment"] = "Successfully installed {0}".format(name)
+        ret["comment"] = "Successfully installed {}".format(name)
         if default_options:
             ret["comment"] += " " + _build_option_string(options)
     else:
-        ret["comment"] = "Failed to install {0}".format(name)
+        ret["comment"] = "Failed to install {}".format(name)
         if err:
-            ret["comment"] += ". Error message:\n{0}".format(err)
+            ret["comment"] += ". Error message:\n{}".format(err)
     return ret
