@@ -33,7 +33,6 @@ import salt.syspaths
 import salt.utils.data
 import salt.utils.event
 import salt.utils.versions
-from salt.features import features
 
 log = logging.getLogger(__name__)
 
@@ -812,11 +811,11 @@ def runner(name, **kwargs):
         "executed" if success else "failed",
     )
 
-    if features.get("enable_deprecated_orchestration_flag", False):
+    if __opts__["features"].get("enable_deprecated_orchestration_flag", False):
         ret["__orchestration__"] = True
         salt.utils.versions.warn_until(
-            "Argon",
-            "The __orchestration__ return flag will be removed in Salt Argon. "
+            3008,
+            "The __orchestration__ return flag will be removed in {version}. "
             "For more information see https://github.com/saltstack/salt/pull/59917.",
         )
 
@@ -1041,7 +1040,7 @@ def wheel(name, **kwargs):
         jid = None
 
     if __opts__.get("test", False):
-        ret["result"] = (None,)
+        ret["result"] = None
         ret["changes"] = {}
         ret["comment"] = "Wheel function '{}' would be executed.".format(name)
         return ret
@@ -1061,7 +1060,7 @@ def wheel(name, **kwargs):
         "executed" if success else "failed",
     )
 
-    if features.get("enable_deprecated_orchestration_flag", False):
+    if __opts__["features"].get("enable_deprecated_orchestration_flag", False):
         ret["__orchestration__"] = True
         salt.utils.versions.warn_until(
             "Argon",
