@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manage X509 Certificates
 
@@ -6,6 +5,19 @@ Manage X509 Certificates
 
 :depends: M2Crypto
 
+.. deprecated:: 3006.0
+
+.. warning::
+    This module has been deprecated and will be removed
+    in Salt 3009 (Potassium). Please migrate to the replacement
+    modules. For breaking changes between both versions,
+    you can refer to the :ref:`x509_v2 execution module docs <x509-setup>`.
+
+    They will become the default ``x509`` modules in Salt 3008 (Argon).
+    You can explicitly switch to the new modules before that release
+    by setting ``features: {x509_v2: true}`` in your minion configuration.
+
+
 This module can enable managing a complete PKI infrastructure including creating private keys, CAs,
 certificates and CRLs. It includes the ability to generate a private key on a server, and have the
 corresponding public key sent to a remote CA to create a CA signed certificate. This can be done in
@@ -24,7 +36,7 @@ For remote signing, peers must be permitted to remotely call the
 
     peer:
       .*:
-        - sign_remote_certificate
+        - x509.sign_remote_certificate
 
 
 /srv/salt/top.sls
@@ -47,25 +59,25 @@ the mine where it can be easily retrieved by other minions.
 
 .. code-block:: yaml
 
-    salt-minion:
-      service.running:
-        - enable: True
-        - watch:
-          - file: /etc/salt/minion.d/x509.conf
-
     /etc/salt/minion.d/x509.conf:
       file.managed:
         - source: salt://x509.conf
 
+    restart-salt-minion:
+      cmd.run:
+        - name: 'salt-call service.restart salt-minion'
+        - bg: True
+        - onchanges:
+          - file: /etc/salt/minion.d/x509.conf
+
     /etc/pki:
       file.directory
 
     /etc/pki/issued_certs:
       file.directory
 
-    /etc/pki/ca.crt:
+    /etc/pki/ca.key:
       x509.private_key_managed:
-        - name: /etc/pki/ca.key
         - bits: 4096
         - backup: True
 
@@ -170,7 +182,6 @@ be considered valid.
         - backup: True
 
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import copy
 import datetime
@@ -193,7 +204,14 @@ def __virtual__():
     """
     only load this module if the corresponding execution module is loaded
     """
+    if __opts__["features"].get("x509_v2"):
+        return (False, "Superseded, using x509_v2")
     if "x509.get_pem_entry" in __salt__:
+        salt.utils.versions.warn_until(
+            "Potassium",
+            "The x509 modules are deprecated. Please migrate to the replacement "
+            "modules (x509_v2). They are the default from Salt 3008 (Argon) onwards.",
+        )
         return "x509"
     else:
         return (False, "Could not load x509 state: m2crypto unavailable")
@@ -324,7 +342,7 @@ def private_key_managed(
         name, bits=bits, passphrase=passphrase, new=new, overwrite=overwrite
     ):
         file_args["contents"] = __salt__["x509.get_pem_entry"](
-            name, pem_type="RSA PRIVATE KEY"
+            name, pem_type="(?:RSA )?PRIVATE KEY"
         )
     else:
         new_key = True
@@ -372,7 +390,7 @@ def csr_managed(name, **kwargs):
     try:
         old = __salt__["x509.read_csr"](name)
     except salt.exceptions.SaltInvocationError:
-        old = "{0} is not a valid csr.".format(name)
+        old = "{} is not a valid csr.".format(name)
 
     file_args, kwargs = _get_file_args(name, **kwargs)
     file_args["contents"] = __salt__["x509.create_csr"](text=True, **kwargs)
@@ -402,12 +420,13 @@ def _certificate_info_matches(cert_info, required_cert_info, check_serial=False)
     ignored_keys = [
         "Not Before",
         "Not After",
-        "MD5 Finger Print",
         "SHA1 Finger Print",
         "SHA-256 Finger Print",
         # The integrity of the issuer is checked elsewhere
         "Issuer Public Key",
     ]
+    if __opts__["fips_mode"] is False:
+        ignored_keys.append("MD5 Finger Print")
     for key in ignored_keys:
         cert_info.pop(key, None)
         required_cert_info.pop(key, None)
@@ -431,6 +450,9 @@ def _certificate_info_matches(cert_info, required_cert_info, check_serial=False)
 
     diff = []
     for k, v in required_cert_info.items():
+        # cert info comes as byte string
+        if isinstance(v, str):
+            v = salt.utils.stringutils.to_bytes(v)
         try:
             if v != cert_info[k]:
                 if k == "Subject Hash":
@@ -495,7 +517,7 @@ def _certificate_is_valid(name, days_remaining, append_certs, **cert_spec):
     If False, also provide a message explaining why.
     """
     if not os.path.isfile(name):
-        return False, "{0} does not exist".format(name), {}
+        return False, "{} does not exist".format(name), {}
 
     try:
         cert_info = __salt__["x509.read_certificate"](certificate=name)
@@ -504,7 +526,7 @@ def _certificate_is_valid(name, days_remaining, append_certs, **cert_spec):
         )
         if not isinstance(required_cert_info, dict):
             raise salt.exceptions.SaltInvocationError(
-                "Unable to create new certificate: x509 module error: {0}".format(
+                "Unable to create new certificate: x509 module error: {}".format(
                     required_cert_info
                 )
             )
@@ -532,7 +554,7 @@ def _certificate_is_valid(name, days_remaining, append_certs, **cert_spec):
         if not matches:
             return (
                 False,
-                "Certificate properties are different: {0}".format(", ".join(diff)),
+                "Certificate properties are different: {}".format(", ".join(diff)),
                 cert_info,
             )
 
@@ -540,15 +562,14 @@ def _certificate_is_valid(name, days_remaining, append_certs, **cert_spec):
         if days_remaining != 0 and actual_days_remaining < days_remaining:
             return (
                 False,
-                "Certificate needs renewal: {0} days remaining but it needs to be at least {1}".format(
-                    actual_days_remaining, days_remaining
-                ),
+                "Certificate needs renewal: {} days remaining but it needs to be at"
+                " least {}".format(actual_days_remaining, days_remaining),
                 cert_info,
             )
 
         return True, "", cert_info
     except salt.exceptions.SaltInvocationError as e:
-        return False, "{0} is not a valid certificate: {1}".format(name, str(e)), {}
+        return False, "{} is not a valid certificate: {}".format(name, str(e)), {}
 
 
 def _certificate_file_managed(ret, file_args):
@@ -560,7 +581,7 @@ def _certificate_file_managed(ret, file_args):
 
     ret["result"] = file_ret["result"]
     if ret["result"]:
-        ret["comment"] = "Certificate {0} is valid and up to date".format(ret["name"])
+        ret["comment"] = "Certificate {} is valid and up to date".format(ret["name"])
     else:
         ret["comment"] = file_ret["comment"]
 
@@ -570,9 +591,7 @@ def _certificate_file_managed(ret, file_args):
     return ret
 
 
-def certificate_managed(
-    name, days_remaining=90, append_certs=None, managed_private_key=None, **kwargs
-):
+def certificate_managed(name, days_remaining=90, append_certs=None, **kwargs):
     """
     Manage a Certificate
 
@@ -590,10 +609,6 @@ def certificate_managed(
         A list of certificates to be appended to the managed file.
         They must be valid PEM files, otherwise an error will be thrown.
 
-    managed_private_key:
-        Has no effect since v2016.11 and will be removed in Salt Aluminium.
-        Use a separate x509.private_key_managed call instead.
-
     kwargs:
         Any arguments supported by :py:func:`x509.create_certificate
         <salt.modules.x509.create_certificate>` or :py:func:`file.managed
@@ -651,16 +666,13 @@ def certificate_managed(
             "signing_policy must be specified if ca_server is."
         )
 
-    if "public_key" not in kwargs and "signing_private_key" not in kwargs:
+    if (
+        "public_key" not in kwargs
+        and "signing_private_key" not in kwargs
+        and "csr" not in kwargs
+    ):
         raise salt.exceptions.SaltInvocationError(
-            "public_key or signing_private_key must be specified."
-        )
-
-    if managed_private_key:
-        salt.utils.versions.warn_until(
-            "Aluminium",
-            "Passing 'managed_private_key' to x509.certificate_managed has no effect and "
-            "will be removed Salt Aluminium. Use a separate x509.private_key_managed call instead.",
+            "public_key, signing_private_key, or csr must be specified."
         )
 
     ret = {"name": name, "result": False, "changes": {}, "comment": ""}
@@ -686,7 +698,7 @@ def certificate_managed(
         ret = _certificate_file_managed(ret, file_args)
 
         ret["result"] = None
-        ret["comment"] = "Certificate {0} will be created".format(name)
+        ret["comment"] = "Certificate {} will be created".format(name)
         ret["changes"]["Status"] = {
             "Old": invalid_reason,
             "New": "Certificate will be valid and up to date",
@@ -699,10 +711,9 @@ def certificate_managed(
         __salt__["x509.read_certificate"](contents)
     except salt.exceptions.SaltInvocationError as e:
         ret["result"] = False
-        ret[
-            "comment"
-        ] = "An error occurred creating the certificate {0}. The result returned from x509.create_certificate is not a valid PEM file:\n{1}".format(
-            name, str(e)
+        ret["comment"] = (
+            "An error occurred creating the certificate {}. The result returned from"
+            " x509.create_certificate is not a valid PEM file:\n{}".format(name, str(e))
         )
         return ret
 
@@ -716,10 +727,11 @@ def certificate_managed(
             contents += append_file_contents
         except salt.exceptions.SaltInvocationError as e:
             ret["result"] = False
-            ret[
-                "comment"
-            ] = "{0} is not a valid certificate file, cannot append it to the certificate {1}.\nThe error returned by the x509 module was:\n{2}".format(
-                append_file, name, str(e)
+            ret["comment"] = (
+                "{} is not a valid certificate file, cannot append it to the"
+                " certificate {}.\nThe error returned by the x509 module was:\n{}".format(
+                    append_file, name, str(e)
+                )
             )
             return ret
 
@@ -833,9 +845,9 @@ def crl_managed(
             if days_remaining == 0:
                 days_remaining = current_days_remaining - 1
         except salt.exceptions.SaltInvocationError:
-            current = "{0} is not a valid CRL.".format(name)
+            current = "{} is not a valid CRL.".format(name)
     else:
-        current = "{0} does not exist.".format(name)
+        current = "{} does not exist.".format(name)
 
     new_crl = __salt__["x509.create_crl"](
         text=True,
