@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
 """
 The check Thorium state is used to create gateways to commands, the checks
 make it easy to make states that watch registers for changes and then just
 succeed or fail based on the state of the register, this creates the pattern
 of having a command execution get gated by a check state via a requisite.
 """
-# import python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 
@@ -38,7 +35,7 @@ def gt(name, value):
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     if __reg__[name]["val"] > value:
         ret["result"] = True
@@ -68,7 +65,7 @@ def gte(name, value):
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     if __reg__[name]["val"] >= value:
         ret["result"] = True
@@ -98,7 +95,7 @@ def lt(name, value):
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     if __reg__[name]["val"] < value:
         ret["result"] = True
@@ -128,7 +125,7 @@ def lte(name, value):
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     if __reg__[name]["val"] <= value:
         ret["result"] = True
@@ -158,7 +155,7 @@ def eq(name, value):
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     if __reg__[name]["val"] == value:
         ret["result"] = True
@@ -188,7 +185,7 @@ def ne(name, value):
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     if __reg__[name]["val"] != value:
         ret["result"] = True
@@ -227,7 +224,7 @@ def contains(
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     try:
         count_compare = (
@@ -308,7 +305,7 @@ def len_gt(name, value):
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     if len(__reg__[name]["val"]) > value:
         ret["result"] = True
@@ -338,7 +335,7 @@ def len_gte(name, value):
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     if len(__reg__[name]["val"]) >= value:
         ret["result"] = True
@@ -368,7 +365,7 @@ def len_lt(name, value):
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     if len(__reg__[name]["val"]) < value:
         ret["result"] = True
@@ -398,7 +395,7 @@ def len_lte(name, value):
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     if len(__reg__[name]["val"]) <= value:
         ret["result"] = True
@@ -428,7 +425,7 @@ def len_eq(name, value):
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     if __reg__[name]["val"] == value:
         ret["result"] = True
@@ -458,7 +455,7 @@ def len_ne(name, value):
     ret = {"name": name, "result": False, "comment": "", "changes": {}}
     if name not in __reg__:
         ret["result"] = False
-        ret["comment"] = "Value {0} not in register".format(name)
+        ret["comment"] = "Value {} not in register".format(name)
         return ret
     if len(__reg__[name]["val"]) != value:
         ret["result"] = True
