@@ -13,7 +13,6 @@ import salt.utils.args
 import salt.utils.data
 import salt.utils.dockermod.translate
 from salt.exceptions import CommandExecutionError, SaltInvocationError
-from salt.ext import six
 from salt.utils.args import get_function_argspec as _argspec
 from salt.utils.dockermod.translate.helpers import split as _split
 
@@ -25,7 +24,6 @@ except ImportError:
 # These next two imports are only necessary to have access to the needed
 # functions so that we can get argspecs for the container config, host config,
 # and networking config (see the get_client_args() function).
-# pylint: disable=import-error,no-name-in-module
 try:
     import docker.types
 except ImportError:
@@ -34,7 +32,6 @@ try:
     import docker.utils
 except ImportError:
     pass
-# pylint: enable=import-error,no-name-in-module
 
 NOTSET = object()
 
