@@ -1,18 +1,15 @@
-# -*- coding: utf-8 -*-
 """
 Functions for interacting with the job cache
 """
 
-# Import Python libs
-from __future__ import absolute_import, unicode_literals
 
 import logging
 
-# Import Salt libs
 import salt.minion
 import salt.utils.event
 import salt.utils.jid
 import salt.utils.verify
+import salt.utils.versions
 
 log = logging.getLogger(__name__)
 
@@ -38,48 +35,49 @@ def store_job(opts, load, event=None, mminion=None):
         load["tgt_type"] = "glob"
         load["tgt"] = load["id"]
 
-        prep_fstr = "{0}.prep_jid".format(opts["master_job_cache"])
+        prep_fstr = "{}.prep_jid".format(opts["master_job_cache"])
         try:
             load["jid"] = mminion.returners[prep_fstr](
                 nocache=load.get("nocache", False)
             )
         except KeyError:
-            emsg = "Returner '{0}' does not support function prep_jid".format(job_cache)
+            emsg = "Returner '{}' does not support function prep_jid".format(job_cache)
             log.error(emsg)
             raise KeyError(emsg)
         except Exception:  # pylint: disable=broad-except
             log.critical(
-                "The specified '{0}' returner threw a stack trace:\n".format(job_cache),
+                "The specified '%s' returner threw a stack trace:\n",
+                job_cache,
                 exc_info=True,
             )
 
         # save the load, since we don't have it
-        saveload_fstr = "{0}.save_load".format(job_cache)
+        saveload_fstr = "{}.save_load".format(job_cache)
         try:
             mminion.returners[saveload_fstr](load["jid"], load)
         except KeyError:
-            emsg = "Returner '{0}' does not support function save_load".format(
-                job_cache
-            )
+            emsg = "Returner '{}' does not support function save_load".format(job_cache)
             log.error(emsg)
             raise KeyError(emsg)
         except Exception:  # pylint: disable=broad-except
             log.critical(
-                "The specified '{0}' returner threw a stack trace:\n".format(job_cache),
+                "The specified '%s' returner threw a stack trace",
+                job_cache,
                 exc_info=True,
             )
     elif salt.utils.jid.is_jid(load["jid"]):
         # Store the jid
-        jidstore_fstr = "{0}.prep_jid".format(job_cache)
+        jidstore_fstr = "{}.prep_jid".format(job_cache)
         try:
             mminion.returners[jidstore_fstr](False, passed_jid=load["jid"])
         except KeyError:
-            emsg = "Returner '{0}' does not support function prep_jid".format(job_cache)
+            emsg = "Returner '{}' does not support function prep_jid".format(job_cache)
             log.error(emsg)
             raise KeyError(emsg)
         except Exception:  # pylint: disable=broad-except
             log.critical(
-                "The specified '{0}' returner threw a stack trace:\n".format(job_cache),
+                "The specified '%s' returner threw a stack trace",
+                job_cache,
                 exc_info=True,
             )
 
@@ -106,10 +104,10 @@ def store_job(opts, load, event=None, mminion=None):
         return
 
     # otherwise, write to the master cache
-    savefstr = "{0}.save_load".format(job_cache)
-    getfstr = "{0}.get_load".format(job_cache)
-    fstr = "{0}.returner".format(job_cache)
-    updateetfstr = "{0}.update_endtime".format(job_cache)
+    savefstr = "{}.save_load".format(job_cache)
+    getfstr = "{}.get_load".format(job_cache)
+    fstr = "{}.returner".format(job_cache)
+    updateetfstr = "{}.update_endtime".format(job_cache)
     if "fun" not in load and load.get("return", {}):
         ret_ = load.get("return", {})
         if "fun" in ret_:
@@ -123,18 +121,24 @@ def store_job(opts, load, event=None, mminion=None):
         getfstr_func = mminion.returners[getfstr]
         fstr_func = mminion.returners[fstr]
     except KeyError as error:
-        emsg = "Returner '{0}' does not support function {1}".format(job_cache, error)
+        emsg = "Returner '{}' does not support function {}".format(job_cache, error)
         log.error(emsg)
         raise KeyError(emsg)
 
-    if job_cache != "local_cache":
+    save_load = True
+    if job_cache == "local_cache" and mminion.returners[getfstr](load.get("jid", "")):
+        # The job was saved previously.
+        save_load = False
+
+    if save_load:
         try:
             mminion.returners[savefstr](load["jid"], load)
         except KeyError as e:
             log.error("Load does not contain 'jid': %s", e)
         except Exception:  # pylint: disable=broad-except
             log.critical(
-                "The specified '{0}' returner threw a stack trace:\n".format(job_cache),
+                "The specified '%s' returner threw a stack trace",
+                job_cache,
                 exc_info=True,
             )
 
@@ -142,8 +146,7 @@ def store_job(opts, load, event=None, mminion=None):
         mminion.returners[fstr](load)
     except Exception:  # pylint: disable=broad-except
         log.critical(
-            "The specified '{0}' returner threw a stack trace:\n".format(job_cache),
-            exc_info=True,
+            "The specified '%s' returner threw a stack trace", job_cache, exc_info=True
         )
 
     if opts.get("job_cache_store_endtime") and updateetfstr in mminion.returners:
@@ -158,13 +161,13 @@ def store_minions(opts, jid, minions, mminion=None, syndic_id=None):
     if mminion is None:
         mminion = salt.minion.MasterMinion(opts, states=False, rend=False)
     job_cache = opts["master_job_cache"]
-    minions_fstr = "{0}.save_minions".format(job_cache)
+    minions_fstr = "{}.save_minions".format(job_cache)
 
     try:
         mminion.returners[minions_fstr](jid, minions, syndic_id=syndic_id)
     except KeyError:
         raise KeyError(
-            "Returner '{0}' does not support function save_minions".format(job_cache)
+            "Returner '{}' does not support function save_minions".format(job_cache)
         )
 
 
@@ -182,4 +185,21 @@ def get_retcode(ret):
     return retcode
 
 
-# vim:set et sts=4 ts=4 tw=80:
+def get_keep_jobs_seconds(opts):
+    """
+    Temporary function until 'keep_jobs' is fully deprecated,
+    this will prefer 'keep_jobs_seconds', and only use
+    'keep_jobs' as the configuration value if 'keep_jobs_seconds'
+    is unmodified, and 'keep_jobs' is modified (in which case it
+    will emit a deprecation warning).
+    """
+    keep_jobs_seconds = opts.get("keep_jobs_seconds", 86400)
+    keep_jobs = opts.get("keep_jobs", 24)
+    if keep_jobs_seconds == 86400 and keep_jobs != 24:
+        salt.utils.versions.warn_until(
+            "Argon",
+            "The 'keep_jobs' option has been deprecated and replaced with "
+            "'keep_jobs_seconds'.",
+        )
+        keep_jobs_seconds = keep_jobs * 3600
+    return keep_jobs_seconds
