@@ -7,34 +7,38 @@ Utilities supporting modules for Hashicorp Vault. Configuration instructions are
 documented in the execution module docs.
 """
 
-
 import base64
 import logging
 import os
+import string
+import tempfile
 import time
 
 import requests
+
 import salt.crypt
 import salt.exceptions
+import salt.utils.json
 import salt.utils.versions
 
 log = logging.getLogger(__name__)
-logging.getLogger("requests").setLevel(logging.WARNING)
 
 
 # Load the __salt__ dunder if not already loaded (when called from utils-module)
 __salt__ = None
 
 
-def __virtual__():  # pylint: disable=expected-2-blank-lines-found-0
+def __virtual__():
     try:
         global __salt__  # pylint: disable=global-statement
         if not __salt__:
             __salt__ = salt.loader.minion_mods(__opts__)
+            logging.getLogger("requests").setLevel(logging.WARNING)
             return True
     except Exception as e:  # pylint: disable=broad-except
-        log.error("Could not load __salt__: %s", e)
+        log.error("Could not load __salt__: %s", e, exc_info=True)
         return False
+    return True
 
 
 def _get_token_and_url_from_master():
@@ -85,13 +89,11 @@ def _get_token_and_url_from_master():
         )
         raise salt.exceptions.CommandExecutionError(result)
     if not isinstance(result, dict):
-        log.error(
-            "Failed to get token from master! " "Response is not a dict: %s", result
-        )
+        log.error("Failed to get token from master! Response is not a dict: %s", result)
         raise salt.exceptions.CommandExecutionError(result)
     if "error" in result:
         log.error(
-            "Failed to get token from master! " "An error was returned: %s",
+            "Failed to get token from master! An error was returned: %s",
             result["error"],
         )
         raise salt.exceptions.CommandExecutionError(result)
@@ -104,6 +106,7 @@ def _get_token_and_url_from_master():
         "url": result["url"],
         "token": result["token"],
         "verify": result.get("verify", None),
+        "namespace": result.get("namespace"),
         "uses": result.get("uses", 1),
         "lease_duration": result["lease_duration"],
         "issued": result["issued"],
@@ -118,6 +121,8 @@ def get_vault_connection():
 
     def _use_local_config():
         log.debug("Using Vault connection details from local config")
+        # Vault Enterprise requires a namespace
+        namespace = __opts__["vault"].get("namespace")
         try:
             if __opts__["vault"]["auth"]["method"] == "approle":
                 verify = __opts__["vault"].get("verify", None)
@@ -128,7 +133,13 @@ def get_vault_connection():
                     payload = {"role_id": __opts__["vault"]["auth"]["role_id"]}
                     if "secret_id" in __opts__["vault"]["auth"]:
                         payload["secret_id"] = __opts__["vault"]["auth"]["secret_id"]
-                    response = requests.post(url, json=payload, verify=verify)
+                    if namespace is not None:
+                        headers = {"X-Vault-Namespace": namespace}
+                        response = requests.post(
+                            url, headers=headers, json=payload, verify=verify
+                        )
+                    else:
+                        response = requests.post(url, json=payload, verify=verify)
                     if response.status_code != 200:
                         errmsg = "An error occurred while getting a token from approle"
                         raise salt.exceptions.CommandExecutionError(errmsg)
@@ -140,6 +151,8 @@ def get_vault_connection():
                 if _wrapped_token_valid():
                     url = "{}/v1/sys/wrapping/unwrap".format(__opts__["vault"]["url"])
                     headers = {"X-Vault-Token": __opts__["vault"]["auth"]["token"]}
+                    if namespace is not None:
+                        headers["X-Vault-Namespace"] = namespace
                     response = requests.post(url, headers=headers, verify=verify)
                     if response.status_code != 200:
                         errmsg = "An error occured while unwrapping vault token"
@@ -149,6 +162,7 @@ def get_vault_connection():
                     ]
             return {
                 "url": __opts__["vault"]["url"],
+                "namespace": namespace,
                 "token": __opts__["vault"]["auth"]["token"],
                 "verify": __opts__["vault"].get("verify", None),
                 "issued": int(round(time.time())),
@@ -160,6 +174,16 @@ def get_vault_connection():
             )
             raise salt.exceptions.CommandExecutionError(errmsg)
 
+    config = __opts__["vault"].get("config_location")
+    if config:
+        if config not in ["local", "master"]:
+            log.error("config_location must be either local or master")
+            return False
+        if config == "local":
+            return _use_local_config()
+        elif config == "master":
+            return _get_token_and_url_from_master()
+
     if "vault" in __opts__ and __opts__.get("__role", "minion") == "master":
         if "id" in __grains__:
             log.debug("Contacting master for Vault connection details")
@@ -181,8 +205,12 @@ def get_vault_connection():
 
 def del_cache():
     """
-    Delete cache file
+    Delete cache
     """
+    log.debug("Deleting session cache")
+    if "vault_token" in __context__:
+        del __context__["vault_token"]
+
     log.debug("Deleting cache file")
     cache_file = os.path.join(__opts__["cachedir"], "salt_vault_token")
 
@@ -193,6 +221,9 @@ def del_cache():
 
 
 def write_cache(connection):
+    """
+    Write the vault token to cache
+    """
     # If uses is 1 and unlimited_use_token is not true, then this is a single use token and should not be cached
     # In that case, we still want to cache the vault metadata lookup information for paths, so continue on
     if (
@@ -215,7 +246,7 @@ def write_cache(connection):
         # Must have been passed metadata. This is already handled by _get_secret_path_metadata
         #  and does not need to be resaved
         return True
-
+    temp_fp, temp_file = tempfile.mkstemp(dir=__opts__["cachedir"])
     cache_file = os.path.join(__opts__["cachedir"], "salt_vault_token")
     try:
         log.debug("Writing vault cache file")
@@ -224,8 +255,11 @@ def write_cache(connection):
             connection["unlimited_use_token"] = True
         else:
             connection["unlimited_use_token"] = False
-        with salt.utils.files.fpopen(cache_file, "w", mode=0o600) as fp_:
+        with salt.utils.files.fpopen(temp_file, "w", mode=0o600) as fp_:
             fp_.write(salt.utils.json.dumps(connection))
+        os.close(temp_fp)
+        # Atomic operation to pervent race condition with concurrent calls.
+        os.rename(temp_file, cache_file)
         return True
     except OSError:
         log.error(
@@ -272,11 +306,11 @@ def get_cache():
 
     # Determine if ttl still valid
     if ttl10 < cur_time:
-        log.debug("Cached token has expired {} < {}: DELETING".format(ttl10, cur_time))
+        log.debug("Cached token has expired %s < %s: DELETING", ttl10, cur_time)
         del_cache()
         return _gen_new_connection()
     else:
-        log.debug("Token has not expired {} > {}".format(ttl10, cur_time))
+        log.debug("Token has not expired %s > %s", ttl10, cur_time)
     return connection
 
 
@@ -285,6 +319,7 @@ def make_request(
     resource,
     token=None,
     vault_url=None,
+    namespace=None,
     get_token_url=False,
     retry=False,
     **args
@@ -298,6 +333,7 @@ def make_request(
         connection = get_cache()
     token = connection["token"] if not token else token
     vault_url = connection["url"] if not vault_url else vault_url
+    namespace = namespace or connection.get("namespace")
     if "verify" in args:
         args["verify"] = args["verify"]
     else:
@@ -308,6 +344,8 @@ def make_request(
             pass
     url = "{}/{}".format(vault_url, resource)
     headers = {"X-Vault-Token": str(token), "Content-Type": "application/json"}
+    if namespace is not None:
+        headers["X-Vault-Namespace"] = namespace
     response = requests.request(method, url, headers=headers, **args)
     if not response.ok and response.json().get("errors", None) == ["permission denied"]:
         log.info("Permission denied from vault")
@@ -346,7 +384,7 @@ def make_request(
                 log.debug("Deleting token from memory")
                 del __context__["vault_token"]
         else:
-            log.debug("Token has {} uses left".format(connection["uses"]))
+            log.debug("Token has %s uses left", connection["uses"])
             write_cache(connection)
 
     if get_token_url:
@@ -361,10 +399,14 @@ def _selftoken_expired():
     """
     try:
         verify = __opts__["vault"].get("verify", None)
+        # Vault Enterprise requires a namespace
+        namespace = __opts__["vault"].get("namespace")
         url = "{}/v1/auth/token/lookup-self".format(__opts__["vault"]["url"])
         if "token" not in __opts__["vault"]["auth"]:
             return True
         headers = {"X-Vault-Token": __opts__["vault"]["auth"]["token"]}
+        if namespace is not None:
+            headers["X-Vault-Namespace"] = namespace
         response = requests.get(url, headers=headers, verify=verify)
         if response.status_code != 200:
             return True
@@ -381,10 +423,14 @@ def _wrapped_token_valid():
     """
     try:
         verify = __opts__["vault"].get("verify", None)
+        # Vault Enterprise requires a namespace
+        namespace = __opts__["vault"].get("namespace")
         url = "{}/v1/sys/wrapping/lookup".format(__opts__["vault"]["url"])
         if "token" not in __opts__["vault"]["auth"]:
             return False
         headers = {"X-Vault-Token": __opts__["vault"]["auth"]["token"]}
+        if namespace is not None:
+            headers["X-Vault-Namespace"] = namespace
         response = requests.post(url, headers=headers, verify=verify)
         if response.status_code != 200:
             return False
@@ -398,8 +444,11 @@ def _wrapped_token_valid():
 def is_v2(path):
     """
     Determines if a given secret path is kv version 1 or 2
+
     CLI Example:
+
     .. code-block:: bash
+
         salt '*' vault.is_v2 "secret/my/secret"
     """
     ret = {"v2": False, "data": path, "metadata": path, "delete": path, "type": None}
@@ -425,14 +474,19 @@ def is_v2(path):
 def _v2_the_path(path, pfilter, ptype="data"):
     """
     Given a path, a filter, and a path type, properly inject 'data' or 'metadata' into the path
+
     CLI Example:
+
     .. code-block:: python
+
         _v2_the_path('dev/secrets/fu/bar', 'dev/secrets', 'data') => 'dev/secrets/data/fu/bar'
     """
     possible_types = ["data", "metadata", "destroy"]
     assert ptype in possible_types
-    msg = "Path {} already contains {} in the right place - saltstack duct tape?".format(
-        path, ptype
+    msg = (
+        "Path {} already contains {} in the right place - saltstack duct tape?".format(
+            path, ptype
+        )
     )
 
     path = path.rstrip("/").lstrip("/")
@@ -460,8 +514,11 @@ def _v2_the_path(path, pfilter, ptype="data"):
 def _get_secret_path_metadata(path):
     """
     Given a path, query vault to determine mount point, type, and version
+
     CLI Example:
+
     .. code-block:: python
+
         _get_secret_path_metadata('dev/secrets/fu/bar')
     """
     ckey = "vault_secret_path_metadata"
@@ -504,3 +561,53 @@ def _get_secret_path_metadata(path):
         except Exception as err:  # pylint: disable=broad-except
             log.error("Failed to get secret metadata %s: %s", type(err).__name__, err)
     return ret
+
+
+def expand_pattern_lists(pattern, **mappings):
+    """
+    Expands the pattern for any list-valued mappings, such that for any list of
+    length N in the mappings present in the pattern, N copies of the pattern are
+    returned, each with an element of the list substituted.
+
+    pattern:
+        A pattern to expand, for example ``by-role/{grains[roles]}``
+
+    mappings:
+        A dictionary of variables that can be expanded into the pattern.
+
+    Example: Given the pattern `` by-role/{grains[roles]}`` and the below grains
+
+    .. code-block:: yaml
+
+        grains:
+            roles:
+                - web
+                - database
+
+    This function will expand into two patterns,
+    ``[by-role/web, by-role/database]``.
+
+    Note that this method does not expand any non-list patterns.
+    """
+    expanded_patterns = []
+    f = string.Formatter()
+
+    # This function uses a string.Formatter to get all the formatting tokens from
+    # the pattern, then recursively replaces tokens whose expanded value is a
+    # list. For a list with N items, it will create N new pattern strings and
+    # then continue with the next token. In practice this is expected to not be
+    # very expensive, since patterns will typically involve a handful of lists at
+    # most.
+
+    for (_, field_name, _, _) in f.parse(pattern):
+        if field_name is None:
+            continue
+        (value, _) = f.get_field(field_name, None, mappings)
+        if isinstance(value, list):
+            token = "{{{0}}}".format(field_name)
+            expanded = [pattern.replace(token, str(elem)) for elem in value]
+            for expanded_item in expanded:
+                result = expand_pattern_lists(expanded_item, **mappings)
+                expanded_patterns += result
+            return expanded_patterns
+    return [pattern]
