@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Module for running ethtool command
 
@@ -10,12 +9,12 @@ Module for running ethtool command
 :platform:      linux
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
+import os
+
+import salt.utils.path
+from salt.exceptions import CommandExecutionError
 
-# Import third party libs
 try:
     import ethtool
 
@@ -100,7 +99,7 @@ def show_ring(devname):
 
     try:
         ring = ethtool.get_ringparam(devname)
-    except IOError:
+    except OSError:
         log.error("Ring parameters not supported on %s", devname)
         return "Not supported"
 
@@ -124,7 +123,7 @@ def show_coalesce(devname):
 
     try:
         coalesce = ethtool.get_coalesce(devname)
-    except IOError:
+    except OSError:
         log.error("Interrupt coalescing not supported on %s", devname)
         return "Not supported"
 
@@ -148,13 +147,13 @@ def show_driver(devname):
 
     try:
         module = ethtool.get_module(devname)
-    except IOError:
+    except OSError:
         log.error("Driver information not implemented on %s", devname)
         return "Not implemented"
 
     try:
         businfo = ethtool.get_businfo(devname)
-    except IOError:
+    except OSError:
         log.error("Bus information no available on %s", devname)
         return "Not available"
 
@@ -179,7 +178,7 @@ def set_ring(devname, **kwargs):
 
     try:
         ring = ethtool.get_ringparam(devname)
-    except IOError:
+    except OSError:
         log.error("Ring parameters not supported on %s", devname)
         return "Not supported"
 
@@ -196,7 +195,7 @@ def set_ring(devname, **kwargs):
         if changed:
             ethtool.set_ringparam(devname, ring)
         return show_ring(devname)
-    except IOError:
+    except OSError:
         log.error("Invalid ring arguments on %s: %s", devname, ring)
         return "Invalid arguments"
 
@@ -218,7 +217,7 @@ def set_coalesce(devname, **kwargs):
 
     try:
         coalesce = ethtool.get_coalesce(devname)
-    except IOError:
+    except OSError:
         log.error("Interrupt coalescing not supported on %s", devname)
         return "Not supported"
 
@@ -237,7 +236,7 @@ def set_coalesce(devname, **kwargs):
             ethtool.set_coalesce(devname, coalesce)
             # pylint: enable=too-many-function-args
         return show_coalesce(devname)
-    except IOError:
+    except OSError:
         log.error("Invalid coalesce arguments on %s: %s", devname, coalesce)
         return "Invalid arguments"
 
@@ -255,22 +254,22 @@ def show_offload(devname):
 
     try:
         sg = ethtool.get_sg(devname) and "on" or "off"
-    except IOError:
+    except OSError:
         sg = "not supported"
 
     try:
         tso = ethtool.get_tso(devname) and "on" or "off"
-    except IOError:
+    except OSError:
         tso = "not supported"
 
     try:
         ufo = ethtool.get_ufo(devname) and "on" or "off"
-    except IOError:
+    except OSError:
         ufo = "not supported"
 
     try:
         gso = ethtool.get_gso(devname) and "on" or "off"
-    except IOError:
+    except OSError:
         gso = "not supported"
 
     offload = {
@@ -299,7 +298,148 @@ def set_offload(devname, **kwargs):
             value = value == "on" and 1 or 0
             try:
                 ethtool.set_tso(devname, value)
-            except IOError:
+            except OSError:
                 return "Not supported"
 
     return show_offload(devname)
+
+
+def _ethtool_command(devname, *args, **kwargs):
+    """
+    Helper function to build an ethtool command
+    """
+    ethtool = salt.utils.path.which("ethtool")
+    if not ethtool:
+        raise CommandExecutionError("Command 'ethtool' cannot be found")
+    switches = " ".join(arg for arg in args)
+    params = " ".join("{} {}".format(key, val) for key, val in kwargs.items())
+    cmd = "{} {} {} {}".format(ethtool, switches, devname, params).strip()
+    ret = __salt__["cmd.run"](cmd, ignore_retcode=True).splitlines()
+    if ret and ret[0].startswith("Cannot"):
+        raise CommandExecutionError(ret[0])
+    return ret
+
+
+def _validate_params(valid_params, kwargs):
+    """
+    Helper function to validate parameters to ethtool commands. Boolean values
+    will be transformed into ``on`` and ``off`` to match expected syntax.
+    """
+    validated = {}
+    for key, val in kwargs.items():
+        key = key.lower()
+        if key in valid_params:
+            if val is True:
+                val = "on"
+            elif val is False:
+                val = "off"
+            validated[key] = val
+    if not validated:
+        raise CommandExecutionError(
+            "None of the valid parameters were provided: {}".format(valid_params)
+        )
+    return validated
+
+
+def show_pause(devname):
+    """
+    .. versionadded:: 3006.0
+
+    Queries the specified network device for associated pause information
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' ethtool.show_pause <devname>
+    """
+    data = {}
+
+    content = _ethtool_command(devname, "-a")
+
+    for line in content[1:]:
+        if line.strip():
+            (key, value) = (s.strip() for s in line.split(":", 1))
+            data[key] = value == "on"
+
+    return data
+
+
+def set_pause(devname, **kwargs):
+    """
+    .. versionadded:: 3006.0
+
+    Changes the pause parameters of the specified network device
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' ethtool.set_pause <devname> autoneg=off rx=off tx=off
+    """
+    valid_params = ["autoneg", "rx", "tx"]
+    params = _validate_params(valid_params, kwargs)
+    ret = _ethtool_command(devname, "-A", **params)
+    if not ret:
+        return True
+    return ret
+
+
+def show_features(devname):
+    """
+    .. versionadded:: 3006.0
+
+    Queries the specified network device for associated feature information
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' ethtool.show_features <devname>
+    """
+    data = {}
+
+    content = _ethtool_command(devname, "-k")
+
+    for line in content[1:]:
+        if ":" in line:
+            key, value = (s.strip() for s in line.strip().split(":", 1))
+            fixed = "fixed" in value
+            if fixed:
+                value = value.split()[0].strip()
+            data[key.strip()] = {"on": value == "on", "fixed": fixed}
+
+    return data
+
+
+def set_feature(devname, **kwargs):
+    """
+    .. versionadded:: 3006.0
+
+    Changes the feature parameters of the specified network device
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' ethtool.set_feature <devname> sg=off
+    """
+    valid_params = [
+        "rx",
+        "tx",
+        "sg",
+        "tso",
+        "ufo",
+        "gso",
+        "gro",
+        "lro",
+        "rxvlan",
+        "txvlan",
+        "ntuple",
+        "rxhash",
+    ]
+    params = _validate_params(valid_params, kwargs)
+    ret = _ethtool_command(devname, "-K", **params)
+    if not ret:
+        return True
+    return os.linesep.join(ret)
