@@ -30,7 +30,8 @@ def __virtual__():
 
     return (
         False,
-        "The vmm execution module cannot be loaded: either the system is not OpenBSD or the vmctl binary was not found",
+        "The vmm execution module cannot be loaded: either the system is not OpenBSD or"
+        " the vmctl binary was not found",
     )
 
 
@@ -59,7 +60,7 @@ def create_disk(name, size):
         salt '*' vmctl.create_disk /path/to/disk.img size=10G
     """
     ret = False
-    cmd = "vmctl create -s {} {}".format(size, name)
+    cmd = "vmctl create {} -s {}".format(name, size)
 
     result = __salt__["cmd.run_all"](cmd, output_loglevel="trace", python_shell=False)
 
@@ -219,7 +220,12 @@ def start(
 
     if not (name or id):
         raise SaltInvocationError('Must provide either "name" or "id"')
-    
+    elif name:
+        cmd.append(name)
+    else:
+        cmd.append(id)
+        name = _id_to_name(id)
+
     if nics > 0:
         cmd.append("-i {}".format(nics))
 
@@ -237,22 +243,15 @@ def start(
     if local_iface:
         cmd.append("-L")
 
-    if disk and (disks and len(disks) > 0):
+    if disk and disks:
         raise SaltInvocationError('Must provide either "disks" or "disk"')
 
     if disk:
         cmd.extend(["-d", disk])
 
-    if disks and len(disks) > 0:
+    if disks:
         cmd.extend(["-d", x] for x in disks)
 
-    if name:
-        cmd.append(name)
-    else:
-        cmd.append(id)
-        name = _id_to_name(id)
-    log.warning(f'cmd: {cmd}')
-
     # Before attempting to define a new VM, make sure it doesn't already exist.
     # Otherwise return to indicate nothing was changed.
     if len(cmd) > 3:
