@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Manage Apache Modules
 
@@ -17,12 +16,6 @@ Enable and disable apache modules.
         - name: cgi
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
-# Import salt libs
-from salt.ext import six
-
 
 def __virtual__():
     """
@@ -47,25 +40,25 @@ def enabled(name):
     is_enabled = __salt__["apache.check_mod_enabled"](name)
     if not is_enabled:
         if __opts__["test"]:
-            msg = "Apache module {0} is set to be enabled.".format(name)
+            msg = "Apache module {} is set to be enabled.".format(name)
             ret["comment"] = msg
             ret["changes"]["old"] = None
             ret["changes"]["new"] = name
             ret["result"] = None
             return ret
         status = __salt__["apache.a2enmod"](name)["Status"]
-        if isinstance(status, six.string_types) and "enabled" in status:
+        if isinstance(status, str) and "enabled" in status:
             ret["result"] = True
             ret["changes"]["old"] = None
             ret["changes"]["new"] = name
         else:
             ret["result"] = False
-            ret["comment"] = "Failed to enable {0} Apache module".format(name)
-            if isinstance(status, six.string_types):
-                ret["comment"] = ret["comment"] + " ({0})".format(status)
+            ret["comment"] = "Failed to enable {} Apache module".format(name)
+            if isinstance(status, str):
+                ret["comment"] = ret["comment"] + " ({})".format(status)
             return ret
     else:
-        ret["comment"] = "{0} already enabled.".format(name)
+        ret["comment"] = "{} already enabled.".format(name)
     return ret
 
 
@@ -83,23 +76,23 @@ def disabled(name):
     is_enabled = __salt__["apache.check_mod_enabled"](name)
     if is_enabled:
         if __opts__["test"]:
-            msg = "Apache module {0} is set to be disabled.".format(name)
+            msg = "Apache module {} is set to be disabled.".format(name)
             ret["comment"] = msg
             ret["changes"]["old"] = name
             ret["changes"]["new"] = None
             ret["result"] = None
             return ret
         status = __salt__["apache.a2dismod"](name)["Status"]
-        if isinstance(status, six.string_types) and "disabled" in status:
+        if isinstance(status, str) and "disabled" in status:
             ret["result"] = True
             ret["changes"]["old"] = name
             ret["changes"]["new"] = None
         else:
             ret["result"] = False
-            ret["comment"] = "Failed to disable {0} Apache module".format(name)
-            if isinstance(status, six.string_types):
-                ret["comment"] = ret["comment"] + " ({0})".format(status)
+            ret["comment"] = "Failed to disable {} Apache module".format(name)
+            if isinstance(status, str):
+                ret["comment"] = ret["comment"] + " ({})".format(status)
             return ret
     else:
-        ret["comment"] = "{0} already disabled.".format(name)
+        ret["comment"] = "{} already disabled.".format(name)
     return ret
