@@ -11,6 +11,7 @@ import re
 import subprocess
 import tempfile
 import time
+import urllib.request
 import uuid
 
 import salt.client
@@ -24,7 +25,6 @@ import salt.utils.versions
 import salt.version
 import salt.wheel
 from salt.exceptions import SaltClientError, SaltSystemExit
-from salt.ext.six.moves.urllib.request import urlopen as _urlopen
 
 FINGERPRINT_REGEX = re.compile(r"^([a-f0-9]{2}:){15}([a-f0-9]{2})$")
 
@@ -32,38 +32,38 @@ log = logging.getLogger(__name__)
 
 
 def _ping(tgt, tgt_type, timeout, gather_job_timeout):
-    client = salt.client.get_local_client(__opts__["conf_file"])
-    pub_data = client.run_job(
-        tgt, "test.ping", (), tgt_type, "", timeout, "", listen=True
-    )
+    with salt.client.get_local_client(__opts__["conf_file"]) as client:
+        pub_data = client.run_job(
+            tgt, "test.ping", (), tgt_type, "", timeout, "", listen=True
+        )
 
-    if not pub_data:
-        return pub_data
+        if not pub_data:
+            return pub_data
 
-    log.debug(
-        "manage runner will ping the following minion(s): %s",
-        ", ".join(sorted(pub_data["minions"])),
-    )
+        log.debug(
+            "manage runner will ping the following minion(s): %s",
+            ", ".join(sorted(pub_data["minions"])),
+        )
 
-    returned = set()
-    for fn_ret in client.get_cli_event_returns(
-        pub_data["jid"],
-        pub_data["minions"],
-        client._get_timeout(timeout),
-        tgt,
-        tgt_type,
-        gather_job_timeout=gather_job_timeout,
-    ):
+        returned = set()
+        for fn_ret in client.get_cli_event_returns(
+            pub_data["jid"],
+            pub_data["minions"],
+            client._get_timeout(timeout),
+            tgt,
+            tgt_type,
+            gather_job_timeout=gather_job_timeout,
+        ):
 
-        if fn_ret:
-            for mid, _ in fn_ret.items():
-                log.debug("minion '%s' returned from ping", mid)
-                returned.add(mid)
+            if fn_ret:
+                for mid, _ in fn_ret.items():
+                    log.debug("minion '%s' returned from ping", mid)
+                    returned.add(mid)
 
-    not_returned = sorted(set(pub_data["minions"]) - returned)
-    returned = sorted(returned)
+        not_returned = sorted(set(pub_data["minions"]) - returned)
+        returned = sorted(returned)
 
-    return returned, not_returned
+        return returned, not_returned
 
 
 def status(
@@ -223,7 +223,7 @@ def list_state(subset=None, show_ip=False):
     detection (no commands will be sent to minions)
 
     subset : None
-        Pass in a CIDR range to filter minions by IP address.
+        Pass in a list of minion ids.
 
     show_ip : False
         Also show the IP address each minion is connecting from.
@@ -253,7 +253,7 @@ def list_not_state(subset=None, show_ip=False):
     detection (no commands will be sent to minions)
 
     subset : None
-        Pass in a CIDR range to filter minions by IP address.
+        Pass in a list of minion ids.
 
     show_ip : False
         Also show the IP address each minion is connecting from.
@@ -266,15 +266,15 @@ def list_not_state(subset=None, show_ip=False):
     """
     connected = list_state(subset=None, show_ip=show_ip)
 
-    key = salt.key.get_key(__opts__)
-    keys = key.list_keys()
+    with salt.key.get_key(__opts__) as key:
+        keys = key.list_keys()
 
-    not_connected = []
-    for minion in keys[key.ACC]:
-        if minion not in connected and (subset is None or minion in subset):
-            not_connected.append(minion)
+        not_connected = []
+        for minion in keys[key.ACC]:
+            if minion not in connected and (subset is None or minion in subset):
+                not_connected.append(minion)
 
-    return not_connected
+        return not_connected
 
 
 def present(subset=None, show_ip=False):
@@ -285,7 +285,7 @@ def present(subset=None, show_ip=False):
     detection (no commands will be sent to minions)
 
     subset : None
-        Pass in a CIDR range to filter minions by IP address.
+        Pass in a list of minion ids.
 
     show_ip : False
         Also show the IP address each minion is connecting from.
@@ -308,7 +308,7 @@ def not_present(subset=None, show_ip=False):
     detection (no commands will be sent)
 
     subset : None
-        Pass in a CIDR range to filter minions by IP address.
+        Pass in a list of minion ids.
 
     show_ip : False
         Also show the IP address each minion is connecting from.
@@ -331,7 +331,7 @@ def joined(subset=None, show_ip=False):
     detection (no commands will be sent to minions)
 
     subset : None
-        Pass in a CIDR range to filter minions by IP address.
+        Pass in a list of minion ids.
 
     show_ip : False
         Also show the IP address each minion is connecting from.
@@ -354,7 +354,7 @@ def not_joined(subset=None, show_ip=False):
     detection (no commands will be sent)
 
     subset : None
-        Pass in a CIDR range to filter minions by IP address.
+        Pass in a list of minion ids.
 
     show_ip : False
         Also show the IP address each minion is connecting from.
@@ -377,7 +377,7 @@ def allowed(subset=None, show_ip=False):
     detection (no commands will be sent to minions)
 
     subset : None
-        Pass in a CIDR range to filter minions by IP address.
+        Pass in a list of minion ids.
 
     show_ip : False
         Also show the IP address each minion is connecting from.
@@ -400,7 +400,7 @@ def not_allowed(subset=None, show_ip=False):
     detection (no commands will be sent)
 
     subset : None
-        Pass in a CIDR range to filter minions by IP address.
+        Pass in a list of minion ids.
 
     show_ip : False
         Also show the IP address each minion is connecting from.
@@ -423,7 +423,7 @@ def alived(subset=None, show_ip=False):
     detection (no commands will be sent to minions)
 
     subset : None
-        Pass in a CIDR range to filter minions by IP address.
+        Pass in a list of minion ids.
 
     show_ip : False
         Also show the IP address each minion is connecting from.
@@ -446,7 +446,7 @@ def not_alived(subset=None, show_ip=False):
     detection (no commands will be sent)
 
     subset : None
-        Pass in a CIDR range to filter minions by IP address.
+        Pass in a list of minion ids.
 
     show_ip : False
         Also show the IP address each minion is connecting from.
@@ -469,7 +469,7 @@ def reaped(subset=None, show_ip=False):
     detection (no commands will be sent to minions)
 
     subset : None
-        Pass in a CIDR range to filter minions by IP address.
+        Pass in a list of minion ids.
 
     show_ip : False
         Also show the IP address each minion is connecting from.
@@ -492,7 +492,7 @@ def not_reaped(subset=None, show_ip=False):
     detection (no commands will be sent)
 
     subset : None
-        Pass in a CIDR range to filter minions by IP address.
+        Pass in a list of minion ids.
 
     show_ip : False
         Also show the IP address each minion is connecting from.
@@ -522,9 +522,7 @@ def safe_accept(target, tgt_type="glob"):
         salt-run manage.safe_accept my_minion
         salt-run manage.safe_accept minion1,minion2 tgt_type=list
     """
-    salt_key = salt.key.Key(__opts__)
     ssh_client = salt.client.ssh.client.SSHClient()
-
     ret = ssh_client.cmd(target, "key.finger", tgt_type=tgt_type)
 
     failures = {}
@@ -532,7 +530,8 @@ def safe_accept(target, tgt_type="glob"):
         if not FINGERPRINT_REGEX.match(finger):
             failures[minion] = finger
         else:
-            fingerprints = salt_key.finger(minion)
+            with salt.key.Key(__opts__) as salt_key:
+                fingerprints = salt_key.finger(minion)
             accepted = fingerprints.get("minions", {})
             pending = fingerprints.get("minions_pre", {})
             if minion in accepted:
@@ -541,9 +540,10 @@ def safe_accept(target, tgt_type="glob"):
             elif minion not in pending:
                 failures[minion] = "Minion key {} not found by salt-key".format(minion)
             elif pending[minion] != finger:
-                failures[minion] = (
-                    "Minion key {} does not match the key in "
-                    "salt-key: {}".format(finger, pending[minion])
+                failures[
+                    minion
+                ] = "Minion key {} does not match the key in salt-key: {}".format(
+                    finger, pending[minion]
                 )
             else:
                 subprocess.call(["salt-key", "-qya", minion])
@@ -578,7 +578,9 @@ def versions():
     ret = {}
     client = salt.client.get_local_client(__opts__["conf_file"])
     try:
-        minions = client.cmd("*", "test.version", timeout=__opts__["timeout"])
+        minions = client.cmd(
+            "*", "test.version", full_return=True, timeout=__opts__["timeout"]
+        )
     except SaltClientError as client_error:
         print(client_error)
         return ret
@@ -596,11 +598,11 @@ def versions():
     master_version = salt.version.__saltstack_version__
 
     for minion in minions:
-        if not minions[minion]:
+        if not minions[minion] or minions[minion]["retcode"]:
             minion_version = False
             ver_diff = -2
         else:
-            minion_version = salt.version.SaltStackVersion.parse(minions[minion])
+            minion_version = salt.version.SaltStackVersion.parse(minions[minion]["ret"])
             ver_diff = salt.utils.compat.cmp(minion_version, master_version)
 
         if ver_diff not in version_status:
@@ -624,7 +626,7 @@ def versions():
 
 def bootstrap(
     version="develop",
-    script=None,
+    script="https://bootstrap.saltproject.io",
     hosts="",
     script_args="",
     roster="flat",
@@ -640,7 +642,7 @@ def bootstrap(
     version : develop
         Git tag of version to install
 
-    script : https://bootstrap.saltstack.com
+    script : https://bootstrap.saltproject.io/
         URL containing the script to execute
 
     hosts
@@ -695,17 +697,14 @@ def bootstrap(
 
         .. versionadded:: 2016.11.0
 
-
     CLI Example:
 
     .. code-block:: bash
 
         salt-run manage.bootstrap hosts='host1,host2'
-        salt-run manage.bootstrap hosts='host1,host2' version='v0.17'
-        salt-run manage.bootstrap hosts='host1,host2' version='v0.17' script='https://bootstrap.saltstack.com/develop'
+        salt-run manage.bootstrap hosts='host1,host2' version='v3004.2'
+        salt-run manage.bootstrap hosts='host1,host2' version='v3004.2' script='https://bootstrap.saltproject.io/develop'
     """
-    if script is None:
-        script = "https://bootstrap.saltstack.com"
 
     client_opts = __opts__.copy()
     if roster is not None:
@@ -773,7 +772,7 @@ def bootstrap_psexec(
 
     installer_url
         URL of minion installer executable. Defaults to the latest version from
-        https://repo.saltstack.com/windows/
+        https://repo.saltproject.io/windows/
 
     username
         Optional user name for login on remote computer.
@@ -792,16 +791,16 @@ def bootstrap_psexec(
     """
 
     if not installer_url:
-        base_url = "https://repo.saltstack.com/windows/"
-        source = _urlopen(base_url).read()
+        base_url = "https://repo.saltproject.io/windows/"
+        source = urllib.request.urlopen(base_url).read()
         salty_rx = re.compile(
             '>(Salt-Minion-(.+?)-(.+)-Setup.exe)</a></td><td align="right">(.*?)\\s*<'
         )
         source_list = sorted(
-            [
+            (
                 [path, ver, plat, time.strptime(date, "%d-%b-%Y %H:%M")]
                 for path, ver, plat, date in salty_rx.findall(source)
-            ],
+            ),
             key=operator.itemgetter(3),
             reverse=True,
         )
@@ -876,7 +875,10 @@ objShell.Exec("{1}{2}")"""
     # This is to accommodate for reinstalling Salt over an old or broken build,
     # e.g. if the master address is changed, the salt-minion process will fail
     # to authenticate and quit; which means infinite restarts under Windows.
-    batch = "cd /d %TEMP%\nnet stop salt-minion\ndel c:\\salt\\conf\\pki\\minion\\minion_master.pub\n"
+    batch = (
+        "cd /d %TEMP%\nnet stop salt-minion\ndel"
+        " c:\\salt\\conf\\pki\\minion\\minion_master.pub\n"
+    )
 
     # Speaking of command-line hostile, cscript only supports reading a script
     # from a file. Glue it together line by line.
