@@ -19,6 +19,13 @@ If your service states are running into trouble with init system detection,
 please see the :ref:`Overriding Virtual Module Providers <module-provider-override>`
 section of Salt's module documentation to work around possible errors.
 
+For services managed by systemd, the systemd_service module includes a built-in
+feature to reload the daemon when unit files are changed or extended. This
+feature is used automatically by the service state and the systemd_service
+module when running on a systemd minion, so there is no need to set up your own
+methods of reloading the daemon. If you need to manually reload the daemon for
+some reason, you can use the :func:`systemd_service.systemctl_reload <salt.modules.systemd_service.systemctl_reload>` function provided by Salt.
+
 .. note::
     The current status of a service is determined by the return code of the init/rc
     script status command. A status return code of 0 it is considered running.  Any
@@ -103,8 +110,9 @@ def _get_systemd_only(func, kwargs):
                 ret[systemd_arg] = kwargs[systemd_arg]
             else:
                 warnings.append(
-                    "The '{}' argument is not supported by this "
-                    "platform".format(systemd_arg)
+                    "The '{}' argument is not supported by this platform".format(
+                        systemd_arg
+                    )
                 )
     return ret, warnings
 
@@ -121,8 +129,8 @@ def _enabled_used_error(ret):
     ret["result"] = False
     ret["comment"] = (
         'Service {} uses non-existent option "enabled".  '
-        'Perhaps "enable" option was intended?'
-    ).format(ret["name"])
+        'Perhaps "enable" option was intended?'.format(ret["name"])
+    )
     return ret
 
 
@@ -147,18 +155,22 @@ def _enable(name, started, result=True, **kwargs):
     # Check to see if this minion supports enable
     if "service.enable" not in __salt__ or "service.enabled" not in __salt__:
         if started is True:
-            ret["comment"] = (
-                "Enable is not available on this minion, service {} started"
-            ).format(name)
+            ret[
+                "comment"
+            ] = "Enable is not available on this minion, service {} started".format(
+                name
+            )
         elif started is None:
             ret["comment"] = (
                 "Enable is not available on this minion,"
-                " service {} is in the desired state"
-            ).format(name)
+                " service {} is in the desired state".format(name)
+            )
         else:
-            ret["comment"] = (
-                "Enable is not available on this minion, service {} is dead"
-            ).format(name)
+            ret[
+                "comment"
+            ] = "Enable is not available on this minion, service {} is dead".format(
+                name
+            )
         return ret
 
     # Service can be enabled
@@ -166,15 +178,17 @@ def _enable(name, started, result=True, **kwargs):
     if before_toggle_enable_status:
         # Service is enabled
         if started is True:
-            ret["comment"] = ("Service {} is already enabled, and is running").format(
+            ret["comment"] = "Service {} is already enabled, and is running".format(
                 name
             )
         elif started is None:
             # always be sure in this case to reset the changes dict
             ret["changes"] = {}
-            ret["comment"] = (
-                "Service {} is already enabled, and is in the desired state"
-            ).format(name)
+            ret[
+                "comment"
+            ] = "Service {} is already enabled, and is in the desired state".format(
+                name
+            )
         else:
             ret["comment"] = "Service {} is already enabled, and is dead".format(name)
         return ret
@@ -196,17 +210,17 @@ def _enable(name, started, result=True, **kwargs):
             if before_toggle_enable_status != after_toggle_enable_status:
                 ret["changes"][name] = True
             if started is True:
-                ret["comment"] = ("Service {} has been enabled, and is running").format(
+                ret["comment"] = "Service {} has been enabled, and is running".format(
                     name
                 )
             elif started is None:
-                ret["comment"] = (
-                    "Service {} has been enabled, and is in the desired state"
-                ).format(name)
-            else:
-                ret["comment"] = ("Service {} has been enabled, and is dead").format(
+                ret[
+                    "comment"
+                ] = "Service {} has been enabled, and is in the desired state".format(
                     name
                 )
+            else:
+                ret["comment"] = "Service {} has been enabled, and is dead".format(name)
             return ret
     except CommandExecutionError as exc:
         enable_error = exc.strerror
@@ -218,18 +232,19 @@ def _enable(name, started, result=True, **kwargs):
     if started is True:
         ret["comment"] = (
             "Failed when setting service {} to start at boot,"
-            " but the service is running"
-        ).format(name)
+            " but the service is running".format(name)
+        )
     elif started is None:
         ret["comment"] = (
             "Failed when setting service {} to start at boot,"
-            " but the service was already running"
-        ).format(name)
+            " but the service was already running".format(name)
+        )
     else:
-        ret["comment"] = (
-            "Failed when setting service {} to start at boot,"
-            " and the service is dead"
-        ).format(name)
+        ret[
+            "comment"
+        ] = "Failed when setting service {} to start at boot, and the service is dead".format(
+            name
+        )
 
     if enable_error:
         ret["comment"] += ". Additional information follows:\n\n{}".format(enable_error)
@@ -259,18 +274,22 @@ def _disable(name, started, result=True, **kwargs):
     # is enable/disable available?
     if "service.disable" not in __salt__ or "service.disabled" not in __salt__:
         if started is True:
-            ret["comment"] = (
-                "Disable is not available on this minion, service {} started"
-            ).format(name)
+            ret[
+                "comment"
+            ] = "Disable is not available on this minion, service {} started".format(
+                name
+            )
         elif started is None:
             ret["comment"] = (
                 "Disable is not available on this minion,"
-                " service {} is in the desired state"
-            ).format(name)
+                " service {} is in the desired state".format(name)
+            )
         else:
-            ret["comment"] = (
-                "Disable is not available on this minion, service {} is dead"
-            ).format(name)
+            ret[
+                "comment"
+            ] = "Disable is not available on this minion, service {} is dead".format(
+                name
+            )
         return ret
 
     # Service can be disabled
@@ -285,15 +304,17 @@ def _disable(name, started, result=True, **kwargs):
     if before_toggle_disable_status:
         # Service is disabled
         if started is True:
-            ret["comment"] = ("Service {} is already disabled, and is running").format(
+            ret["comment"] = "Service {} is already disabled, and is running".format(
                 name
             )
         elif started is None:
             # always be sure in this case to reset the changes dict
             ret["changes"] = {}
-            ret["comment"] = (
-                "Service {} is already disabled, and is in the desired state"
-            ).format(name)
+            ret[
+                "comment"
+            ] = "Service {} is already disabled, and is in the desired state".format(
+                name
+            )
         else:
             ret["comment"] = "Service {} is already disabled, and is dead".format(name)
         return ret
@@ -314,13 +335,11 @@ def _disable(name, started, result=True, **kwargs):
         if before_toggle_disable_status != after_toggle_disable_status:
             ret["changes"][name] = True
         if started is True:
-            ret["comment"] = ("Service {} has been disabled, and is running").format(
-                name
-            )
+            ret["comment"] = "Service {} has been disabled, and is running".format(name)
         elif started is None:
-            ret["comment"] = (
-                "Service {} has been disabled, and is in the desired state"
-            ).format(name)
+            ret[
+                "comment"
+            ] = "Service {} has been disabled, and is in the desired state".format(name)
         else:
             ret["comment"] = "Service {} has been disabled, and is dead".format(name)
         return ret
@@ -328,22 +347,28 @@ def _disable(name, started, result=True, **kwargs):
     # Service failed to be disabled
     ret["result"] = False
     if started is True:
-        ret["comment"] = (
-            "Failed when setting service {} to not start at boot, and is running"
-        ).format(name)
+        ret[
+            "comment"
+        ] = "Failed when setting service {} to not start at boot, and is running".format(
+            name
+        )
     elif started is None:
         ret["comment"] = (
             "Failed when setting service {} to not start"
-            " at boot, but the service was already running"
-        ).format(name)
+            " at boot, but the service was already running".format(name)
+        )
     else:
         ret["comment"] = (
             "Failed when setting service {} to not start"
-            " at boot, and the service is dead"
-        ).format(name)
+            " at boot, and the service is dead".format(name)
+        )
     return ret
 
 
+def _offline():
+    return "service.offline" in __salt__ and __salt__["service.offline"]()
+
+
 def _available(name, ret):
     """
     Check if the service is available
@@ -438,6 +463,11 @@ def running(name, enable=None, sig=None, init_delay=None, **kwargs):
     if isinstance(enable, str):
         enable = salt.utils.data.is_true(enable)
 
+    if _offline():
+        ret["result"] = True
+        ret["comment"] = "Running in OFFLINE mode. Nothing to do"
+        return ret
+
     # Check if the service is available
     try:
         if not _available(name, ret):
@@ -633,6 +663,11 @@ def dead(name, enable=None, sig=None, init_delay=None, **kwargs):
     if isinstance(enable, str):
         enable = salt.utils.data.is_true(enable)
 
+    if _offline():
+        ret["result"] = True
+        ret["comment"] = "Running in OFFLINE mode. Nothing to do"
+        return ret
+
     # Check if the service is available
     try:
         if not _available(name, ret):
@@ -756,6 +791,14 @@ def enabled(name, **kwargs):
     __context__["service.state"] = "enabled"
 
     ret.update(_enable(name, None, **kwargs))
+    if __opts__.get("test") and ret.get(
+        "comment"
+    ) == "The named service {} is not available".format(name):
+        ret["result"] = None
+        ret["comment"] = (
+            "Service {} not present; if created in this state run, "
+            "it would have been enabled".format(name)
+        )
     return ret
 
 
@@ -833,7 +876,10 @@ def masked(name, runtime=False):
 
     try:
         if __salt__["service.masked"](name, runtime):
-            ret["comment"] = "Service {} is already {}".format(name, mask_type,)
+            ret["comment"] = "Service {} is already {}".format(
+                name,
+                mask_type,
+            )
             return ret
 
         if __opts__["test"]:
@@ -939,22 +985,22 @@ def mod_watch(
         This state exists to support special handling of the ``watch``
         :ref:`requisite <requisites>`. It should not be called directly.
 
-        Parameters for this function should be set by the watching service.
-        (i.e. ``service.running``)
+        Parameters for this function should be set by the watching service
+        (e.g. ``service.running``).
 
     name
-        The name of the init or rc script used to manage the service
+        The name of the service to control.
 
     sfun
         The original function which triggered the mod_watch call
         (`service.running`, for example).
 
     sig
-        The string to search for when looking for the service process with ps
+        The string to search for when looking for the service process with ps.
 
     reload
-        When set, reload the service instead of restarting it.
-        (i.e. ``service nginx reload``)
+        When set, reload the service instead of restarting it
+        (e.g. ``service nginx reload``).
 
     full_restart
         Perform a full stop/start of a service by passing ``--full-restart``.
@@ -962,10 +1008,10 @@ def mod_watch(
         :py:func:`service modules <salt.modules.service>`.
 
     force
-        Use service.force_reload instead of reload (needs reload to be set to True)
+        Use service.force_reload instead of reload (needs reload to be set to True).
 
     init_delay
-        Add a sleep command (in seconds) before the service is restarted/reloaded
+        Add a sleep command (in seconds) before the service is restarted/reloaded.
     """
     ret = {"name": name, "changes": {}, "result": True, "comment": ""}
     past_participle = None
