@@ -8,7 +8,9 @@ import copy
 import datetime
 import fnmatch
 import functools
+import hashlib
 import logging
+import random
 import re
 from collections.abc import Mapping, MutableMapping, Sequence
 
@@ -17,9 +19,6 @@ import salt.utils.stringutils
 import salt.utils.yaml
 from salt.defaults import DEFAULT_TARGET_DELIM
 from salt.exceptions import SaltException
-from salt.ext import six
-from salt.ext.six.moves import range  # pylint: disable=redefined-builtin
-from salt.ext.six.moves import zip  # pylint: disable=redefined-builtin
 from salt.utils.decorators.jinja import jinja_filter
 from salt.utils.odict import OrderedDict
 
@@ -28,6 +27,8 @@ try:
 except ImportError:
     jmespath = None
 
+ALGORITHMS_ATTR_NAME = "algorithms_guaranteed"
+
 log = logging.getLogger(__name__)
 
 
@@ -168,7 +169,7 @@ def _remove_circular_refs(ob, _seen=None):
     This has been taken from author Martijn Pieters
     https://stackoverflow.com/questions/44777369/
     remove-circular-references-in-dicts-lists-tuples/44777477#44777477
-    :param ob: dict, list, typle, set, and frozenset
+    :param ob: dict, list, tuple, set, and frozenset
         Standard python object
     :param object _seen:
         Object that has circular reference
@@ -762,7 +763,7 @@ def filter_by(lookup_dict, lookup, traverse, merge=None, default="default", base
         elif isinstance(base_values, Mapping):
             if not isinstance(ret, Mapping):
                 raise SaltException(
-                    "filter_by default and look-up values must both be " "dictionaries."
+                    "filter_by default and look-up values must both be dictionaries."
                 )
             ret = salt.utils.dictupdate.update(copy.deepcopy(base_values), ret)
 
@@ -890,15 +891,9 @@ def subdict_match(
     """
 
     def _match(target, pattern, regex_match=False, exact_match=False):
-        # The reason for using six.text_type first and _then_ using
-        # to_unicode as a fallback is because we want to eventually have
-        # unicode types for comparison below. If either value is numeric then
-        # six.text_type will turn it into a unicode string. However, if the
-        # value is a PY2 str type with non-ascii chars, then the result will be
-        # a UnicodeDecodeError. In those cases, we simply use to_unicode to
-        # decode it to unicode. The reason we can't simply use to_unicode to
-        # begin with is that (by design) to_unicode will raise a TypeError if a
-        # non-string/bytestring/bytearray value is passed.
+        # XXX: A lot of this logic is here because of supporting PY2 and PY3,
+        # now that we only support PY3 we should probably re-visit what's going
+        # on here.
         try:
             target = str(target).lower()
         except UnicodeDecodeError:
@@ -1080,7 +1075,7 @@ def repack_dictlist(data, strict=False, recurse=False, key_cb=None, val_cb=None)
                 return {}
     else:
         log.error(
-            "Invalid input for repack_dictlist, data passed is not a list " "(%s)", data
+            "Invalid input for repack_dictlist, data passed is not a list (%s)", data
         )
         return {}
 
@@ -1193,8 +1188,8 @@ def mysql_to_dict(data, key):
         if line.startswith("+"):
             continue
         comps = line.split("|")
-        for comp in range(len(comps)):
-            comps[comp] = comps[comp].strip()
+        for idx, comp in enumerate(comps):
+            comps[idx] = comp.strip()
         if len(headers) > 1:
             index = len(headers) - 1
             row = {}
@@ -1252,9 +1247,7 @@ def stringify(data):
     """
     ret = []
     for item in data:
-        if six.PY2 and isinstance(item, str):
-            item = salt.utils.stringutils.to_unicode(item)
-        elif not isinstance(item, str):
+        if not isinstance(item, str):
             item = str(item)
         ret.append(item)
     return ret
@@ -1552,3 +1545,148 @@ def get_value(obj, path, default=None):
         else:
             return [{"value": default if obj is not None else obj}]
     return res
+
+
+@jinja_filter("flatten")
+def flatten(data, levels=None, preserve_nulls=False, _ids=None):
+    """
+    .. versionadded:: 3005
+
+    Flatten a list.
+
+    :param data: A list to flatten
+
+    :param levels: The number of levels in sub-lists to descend
+
+    :param preserve_nulls: Preserve nulls in a list, by default flatten removes
+                           them
+
+    :param _ids: Parameter used internally within the function to detect
+                 reference cycles.
+
+    :returns: A flat(ter) list of values
+
+    .. code-block:: jinja
+
+        {{ [3, [4, 2] ] | flatten }}
+        # => [3, 4, 2]
+
+    Flatten only the first level of a list:
+
+    .. code-block:: jinja
+
+        {{ [3, [4, [2]] ] | flatten(levels=1) }}
+        # => [3, 4, [2]]
+
+    Preserve nulls in a list, by default flatten removes them.
+
+    .. code-block:: jinja
+
+        {{ [3, None, [4, [2]] ] | flatten(levels=1, preserve_nulls=True) }}
+        # => [3, None, 4, [2]]
+    """
+    if _ids is None:
+        _ids = set()
+    if id(data) in _ids:
+        raise RecursionError("Reference cycle detected. Check input list.")
+    _ids.add(id(data))
+
+    ret = []
+
+    for element in data:
+        if not preserve_nulls and element in (None, "None", "null"):
+            # ignore null items
+            continue
+        elif is_iter(element):
+            if levels is None:
+                ret.extend(flatten(element, preserve_nulls=preserve_nulls, _ids=_ids))
+            elif levels >= 1:
+                # decrement as we go down the stack
+                ret.extend(
+                    flatten(
+                        element,
+                        levels=(int(levels) - 1),
+                        preserve_nulls=preserve_nulls,
+                        _ids=_ids,
+                    )
+                )
+            else:
+                ret.append(element)
+        else:
+            ret.append(element)
+
+    return ret
+
+
+def hash(value, algorithm="sha512"):
+    """
+    .. versionadded:: 2014.7.0
+
+    Encodes a value with the specified encoder.
+
+    value
+        The value to be hashed.
+
+    algorithm : sha512
+        The algorithm to use. May be any valid algorithm supported by
+        hashlib.
+    """
+    if isinstance(value, str):
+        # Under Python 3 we must work with bytes
+        value = value.encode(__salt_system_encoding__)
+
+    if hasattr(hashlib, ALGORITHMS_ATTR_NAME) and algorithm in getattr(
+        hashlib, ALGORITHMS_ATTR_NAME
+    ):
+        hasher = hashlib.new(algorithm)
+        hasher.update(value)
+        out = hasher.hexdigest()
+    elif hasattr(hashlib, algorithm):
+        hasher = hashlib.new(algorithm)
+        hasher.update(value)
+        out = hasher.hexdigest()
+    else:
+        raise SaltException("You must specify a valid algorithm.")
+
+    return out
+
+
+@jinja_filter("random_sample")
+def sample(value, size, seed=None):
+    """
+    Return a given sample size from a list. By default, the random number
+    generator uses the current system time unless given a seed value.
+
+    .. versionadded:: 3005
+
+    value
+        A list to e used as input.
+
+    size
+        The sample size to return.
+
+    seed
+        Any value which will be hashed as a seed for random.
+    """
+    if seed is None:
+        ret = random.sample(value, size)
+    else:
+        ret = random.Random(hash(seed)).sample(value, size)
+    return ret
+
+
+@jinja_filter("random_shuffle")
+def shuffle(value, seed=None):
+    """
+    Return a shuffled copy of an input list. By default, the random number
+    generator uses the current system time unless given a seed value.
+
+    .. versionadded:: 3005
+
+    value
+        A list to be used as input.
+
+    seed
+        Any value which will be hashed as a seed for random.
+    """
+    return sample(value, len(value), seed=seed)
